@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: parse.c,v 1.10 2003/04/18 18:32:26 ostborn Exp $
+** $Id: parse.c,v 1.11 2003/07/31 23:56:57 ostborn Exp $
 */
 
 #include <stdlib.h>
@@ -203,8 +203,13 @@ int set_connection_state(mconfig *ext_conf, pid_t pid, time_t timestamp, int sta
 			}
 			conf->connections[i]->lasttstmp = timestamp;
 			if (v1) {
-				conf->connections[i]->username = malloc(strlen(v1) + 1);
-				strcpy(conf->connections[i]->username, v1);
+				if (conf->connections[i]->username) {
+					fprintf(stderr, " !! %s -> %s\n", conf->connections[i]->username, v1);
+					
+					free(conf->connections[i]->username);
+				}
+				
+				conf->connections[i]->username = strdup(v1);
 			}
 			break;
 		}
