@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: parse.c,v 1.76 2003/04/18 18:34:38 ostborn Exp $
+** $Id: parse.c,v 1.79 2003/08/25 10:51:55 ostborn Exp $
 */
 
 #define _GNU_SOURCE
@@ -229,6 +229,7 @@ int parse_url(mconfig *ext_conf,const char *str, mlogrec_web *record) {
 
 	const char *method_end, *uri, *get, *protocol, *protocol_end;
 	int len = strlen(str);
+	config_input *conf = ext_conf->plugin_conf;
 
 	if (len == 1 && *str == '-') {
 /* if the url is '-' we don't have to cry about it.
@@ -243,9 +244,10 @@ int parse_url(mconfig *ext_conf,const char *str, mlogrec_web *record) {
 	/* 3 parts, 3rd is optional */
 	method_end = uri = strchr(str, ' ');
 	if (!uri) return M_RECORD_CORRUPT;
-		
+	
 	uri++;
-	if (uri[0] == 'h' &&
+	if( !conf->dont_strip_hostname &&
+	    uri[0] == 'h' &&
 	    uri[1] == 't' &&
 	    uri[2] == 't' &&
 	    uri[3] == 'p') {
@@ -273,12 +275,13 @@ int parse_url(mconfig *ext_conf,const char *str, mlogrec_web *record) {
 	if (protocol_end > uri ) {
 		protocol = memrchr(str, ' ', protocol_end - str);
 		if (protocol <= uri) protocol = NULL;
-	} else
+	} else {
 		protocol = NULL;
-
+	}
+	
 	if (protocol) {
 		buffer_strcpy_len(record->req_url, uri, protocol - uri);
-		if ((get = strchr(uri, '?'))) {
+		if ((get = memchr(uri, '?', protocol - uri))) {
 			buffer_strcpy_len(record->req_getvars, get+1, protocol - (get + 1));
 		}
 		
@@ -525,7 +528,7 @@ int parse_record_dynamic(mconfig *ext_conf, mlogrec *record, buffer *b) {
 			break;
 		case M_CLF_FIELD_REQ_HOST:
 			if (is_ip(list[i+1])) {
-				if (!recweb->req_host_ip) {
+				if (!recweb->req_host_ip->used) {
 					buffer_strcpy(recweb->req_host_ip, (char *)list[i+1]);
 				}
 			} else {
@@ -533,7 +536,7 @@ int parse_record_dynamic(mconfig *ext_conf, mlogrec *record, buffer *b) {
 			}
 			break;
 		case M_CLF_FIELD_REMOTE_IP:
-			if (!recweb->req_host_ip) {
+			if (!recweb->req_host_ip->used) {
 				buffer_strcpy(recweb->req_host_ip, (char *)list[i+1]);
 			}
 			break;
