@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.c,v 1.40 2003/04/18 18:34:38 ostborn Exp $
+** $Id: plugin_config.c,v 1.41 2003/05/15 13:04:04 miham Exp $
 */
 
 #include <stdlib.h>
@@ -61,6 +61,7 @@ int mplugins_input_clf_dlinit(mconfig *ext_conf) {
 	conf->match_useragent = mlist_init();
 	conf->record_list = mlist_init();
 	conf->inputfilename = NULL;
+	conf->dont_strip_hostname = 0;
 
 	/* will be replaced by setdefaults if we have a real inputfilename */
 	conf->buf = buffer_init();
@@ -95,6 +96,8 @@ int mplugins_input_clf_dlclose(mconfig *ext_conf) {
 	mlist_free(conf->match_useragent);
 	mlist_free(conf->record_list);
 
+	if (conf->match_clf) pcre_free(conf->match_clf);
+
 	buffer_free(conf->buf);
 	if (conf->format) free(conf->format);
 	
@@ -116,6 +119,7 @@ int mplugins_input_clf_parse_config(mconfig *ext_conf, const char *filename, con
 		{"match_useragent",	M_CONFIG_TYPE_SUBSTITUTE,	M_CONFIG_VALUE_APPEND, &(conf->match_useragent)},
 		{"inputfile",	M_CONFIG_TYPE_STRING,	M_CONFIG_VALUE_OVERWRITE, &(conf->inputfilename)},
 		{"format",	M_CONFIG_TYPE_STRING,	M_CONFIG_VALUE_OVERWRITE, &(conf->format)},
+		{"dont_strip_hostname",	M_CONFIG_TYPE_INT, 	M_CONFIG_VALUE_OVERWRITE, (&conf->dont_strip_hostname)},
 
 		{NULL, M_CONFIG_TYPE_INT, 0, NULL}
 	};
@@ -385,6 +389,10 @@ int mplugins_input_clf_set_defaults(mconfig *ext_conf) {
 		}
 	}
 
+	if (!conf->dont_strip_hostname) {
+		conf->dont_strip_hostname = 0;
+	}
+	
 	return 0;
 }
 
