@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: parse.c,v 1.24 2003/04/18 18:37:28 ostborn Exp $
+** $Id: parse.c,v 1.25 2003/08/05 12:01:55 ostborn Exp $
 */
 
 #include <stdlib.h>
@@ -379,7 +379,7 @@ int parse_msiis_field_info(mconfig *ext_conf, const char *_buffer) {
 	match_buf = buffer_init();
 
 	for (i = 0; i < pos; i++) {
-		if (match_buf == 0) {
+		if (match_buf->used == 0) {
 			buffer_strcpy(match_buf, "^");
 		} else {
 			buffer_strcat(match_buf, " ");
