@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: parse.c,v 1.19 2003/04/18 18:40:45 ostborn Exp $
+** $Id: parse.c,v 1.20 2003/05/17 18:53:53 miham Exp $
 */
 
 #include <stdlib.h>
@@ -149,7 +149,7 @@ int parse_record_pcre(mconfig *ext_conf, mlogrec *record, buffer *b) {
 	       T: file was tar'ed
 	       _: no action was taken
 	   8 - direction
-	       i: incomming
+	       i: incoming
 	       o: outgoing
 	   9 - access-mode
 	       a: anonymous
