@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: main.c,v 1.104 2003/04/18 18:14:29 ostborn Exp $
+** $Id: main.c,v 1.111 2003/08/25 10:27:37 ostborn Exp $
 */
 
 /**
@@ -128,7 +128,8 @@ int restore_internal_state (mconfig *conf, mlist *state_list) {
 	strcat(fn, "/modlogan.statefiles");
 
 	if ((split_file = fopen(fn, "r")) == NULL) {
-		fprintf(stderr, "%s.%d: can't open %s: %s, first run ?\n", __FILE__, __LINE__, fn, strerror(errno));
+		M_DEBUG2(conf->debug_level, M_DEBUG_SECTION_INIT, M_DEBUG_LEVEL_ERRORS,
+			 "NOTICE: can't open %s: %s, <- ignore this message on the first run\n", fn, strerror(errno));
 		
 		free(fn);
 		return 0;
@@ -235,10 +236,11 @@ int get_next_record (mconfig *conf, mlogrec *rec) {
 
 	}
 
+	/* fill the read-ahead-buffer */
 	for (j = 0; j < conf->read_ahead_limit; j++) {
 		if (last_rec_state != M_RECORD_EOF &&
 		    readahead[j]->record->timestamp == 0) {
-			/* is free */
+			/* slot is free */
 
 			ndx = -1;
 			t = -1;
@@ -268,8 +270,16 @@ int get_next_record (mconfig *conf, mlogrec *rec) {
 						}
 					}
 
-					if (t == -1 || recs[i]->record->timestamp < t) {
-						t = recs[i]->record->timestamp;
+#if 0					
+					fprintf(stderr, "%s.%d: %d %d\n", 
+						__FILE__, __LINE__, 
+						recs[i]->record->timestamp,
+						t);
+#endif
+					if ((recs[i]->record->timestamp > 0) &&    /* valid timestamp */
+					    ((t == -1) ||                          /* first result */
+					     (recs[i]->record->timestamp < t))) {  /* oldest timestamp */
+						t = recs[i]->record->timestamp; 
 						ndx = i;
 					}
 				}
@@ -292,7 +302,7 @@ int get_next_record (mconfig *conf, mlogrec *rec) {
 		}
 
 		/* select the oldest record from our readahead storage */
-		if (readahead[j]->record->ext_type != M_RECORD_TYPE_UNSET) {
+		if (readahead[j]->record->timestamp != 0) {
 			if  (rt == -1 || readahead[j]->record->timestamp < rt) {
 				rt = readahead[j]->record->timestamp;
 				rndx = j;
@@ -611,6 +621,8 @@ int main (int argc, char **argv) {
 	MTIMER_START(setup_timer);
 
 	if (mconfig_read(conf, conf_filename)) {
+		mconfig_free(conf);
+		
 		fprintf(stderr, "%s.%d: reading configfile failed - going down hard\n", __FILE__, __LINE__);
 		return -1;
 	}
@@ -624,11 +636,16 @@ int main (int argc, char **argv) {
 	}
 
 	state_list = mlist_init();
-	rec = mrecord_init();
 
 	if (restore_internal_state(conf, state_list)) {
+		
+		mconfig_free(conf);
+		mlist_free(state_list);
+		
 		return -1;
 	}
+	
+	rec = mrecord_init();
 
 	if (conf->incremental) {
 		l = state_list;
@@ -655,7 +672,7 @@ int main (int argc, char **argv) {
 	}
 
 	M_DEBUG0(conf->debug_level, M_DEBUG_SECTION_INIT, M_DEBUG_LEVEL_NONE,
-		"startup - finished\n");
+		"NOTICE: startup - finished\n");
 
 	MTIMER_STOP(setup_timer);
 	MTIMER_CALC(setup_timer);
@@ -979,6 +996,9 @@ int main (int argc, char **argv) {
 				break;
 			case M_STATE_TYPE_TRAFFIC:
 				break;
+			case M_STATE_TYPE_IPPL:
+				//histdata = mdata_Ipplhist_create_by_state(state);
+				break;
 			case M_STATE_TYPE_UNSET:
 				if (state->ext) {
 					M_DEBUG0(conf->debug_level, M_DEBUG_SECTION_MAINLOOP, M_DEBUG_LEVEL_ERRORS,
