@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mconfig.c,v 1.73 2003/04/18 18:17:52 ostborn Exp $
+** $Id: mconfig.c,v 1.76 2003/07/31 23:56:08 ostborn Exp $
 */
 
 #define _GNU_SOURCE
@@ -576,15 +576,18 @@ int mconfig_handle_cmdlineopts(mconfig *conf, const char *section, const mconfig
 
 int mconfig_parse_section(mconfig *conf, const char *cf, const char *section, const mconfig_values config_values[]) {
 	FILE *f;
-	const char *errptr;
-	int erroffset = 0;
 	int current_group = M_CONFIG_GROUP_DONT_PARSE_ME;
 	char buf[255];
 	int locale_is_not_setup_yet = 1;
 	int ln = 0;
 	const char *old_fn;
-	pcre * match_comment, *match_group, *match_keyvalue, *match_include, *match_variable;
 	int base_level;
+	int ret = 0;
+	const char *errptr;
+	int erroffset = 0;
+	
+	
+	pcre * match_comment, *match_group, *match_keyvalue, *match_include, *match_variable;
 
 	enum { M_CONFIG_LINE_UNSET, M_CONFIG_LINE_GROUP, M_CONFIG_LINE_COMMENT, M_CONFIG_LINE_KEYVALUE, M_CONFIG_LINE_VARIABLE };
 	
@@ -592,6 +595,8 @@ int mconfig_parse_section(mconfig *conf, const char *cf, const char *section, co
 	
 	old_fn = filename;
 	filename = cf ? cf : conf->configfile;
+	
+	match_comment = match_group = match_keyvalue = match_include = match_variable = NULL;
 
 	if (conf->show_options) {
 		mconfig_show_options(section, config_values);
@@ -609,19 +614,12 @@ int mconfig_parse_section(mconfig *conf, const char *cf, const char *section, co
 		filename = old_fn;
 		return -1;
 	}
-
-#ifdef DEBUG
-	fprintf(stderr, "%s.%d: (config) %s - starting\n", __FILE__, __LINE__, filename);
-#endif
-
-	/* setup the parser */
-
+	
 	if ((match_comment = pcre_compile(
 		"^\\s*#",
 		0, &errptr, &erroffset, NULL)) == NULL) {
 
 		fprintf(stderr, "%s.%d: rexexp compilation error at %s\n", __FILE__, __LINE__, errptr);
-		filename = old_fn;
 		return -1;
 	}
 
@@ -630,7 +628,6 @@ int mconfig_parse_section(mconfig *conf, const char *cf, const char *section, co
 		0, &errptr, &erroffset, NULL)) == NULL) {
 
 		fprintf(stderr, "%s.%d: rexexp compilation error at %s\n", __FILE__, __LINE__, errptr);
-		filename = old_fn;
 		return -1;
 	}
 
@@ -639,7 +636,6 @@ int mconfig_parse_section(mconfig *conf, const char *cf, const char *section, co
 		0, &errptr, &erroffset, NULL)) == NULL) {
 
 		fprintf(stderr, "%s.%d: rexexp compilation error at %s\n", __FILE__, __LINE__, errptr);
-		filename = old_fn;
 		return -1;
 	}
 
@@ -648,7 +644,6 @@ int mconfig_parse_section(mconfig *conf, const char *cf, const char *section, co
 		0, &errptr, &erroffset, NULL)) == NULL) {
 
 		fprintf(stderr, "%s.%d: rexexp compilation error at %s\n", __FILE__, __LINE__, errptr);
-		filename = old_fn;
 		return -1;
 	}
 
@@ -657,10 +652,12 @@ int mconfig_parse_section(mconfig *conf, const char *cf, const char *section, co
 		0, &errptr, &erroffset, NULL)) == NULL) {
 
 		fprintf(stderr, "%s.%d: rexexp compilation error at %s\n", __FILE__, __LINE__, errptr);
-		filename = old_fn;
 		return -1;
 	}
 
+#ifdef DEBUG
+	fprintf(stderr, "%s.%d: (config) %s - starting\n", __FILE__, __LINE__, filename);
+#endif
 
 	while (fgets(buf, sizeof(buf)-1, f)) {
 	#define N 20 + 1
@@ -712,6 +709,7 @@ int mconfig_parse_section(mconfig *conf, const char *cf, const char *section, co
 			if ((n = pcre_exec(match_comment, NULL, buf, buf_len, 0, 0, ovector, 3 * N)) < 0) {
 				if (n != PCRE_ERROR_NOMATCH) {
 					fprintf(stderr, "%s.%d: execution error while matching: %d\n", __FILE__, __LINE__, n);
+					
 					filename = old_fn;
 					return -1;
 				}
@@ -887,6 +885,11 @@ int mconfig_parse_section(mconfig *conf, const char *cf, const char *section, co
 
 					if (mconfig_parse_section(conf, inc_list[1], inc_list[2], config_values)) {
 						fprintf(stderr, "%s.%d: parsing included configfile failed (%s)\n", __FILE__, __LINE__, inc_list[1]);
+						
+						fclose(f);
+						pcre_free_substring_list(list);
+						pcre_free_substring_list(inc_list);
+						
 						filename = old_fn;
 						return -1;
 					}
@@ -922,18 +925,20 @@ int mconfig_parse_section(mconfig *conf, const char *cf, const char *section, co
 	}
 
 	fclose (f);
-
+	
 	pcre_free(match_comment);
 	pcre_free(match_group);
 	pcre_free(match_keyvalue);
 
 	pcre_free(match_include);
 	pcre_free(match_variable);
+	
+
 #ifdef DEBUG
 	fprintf(stderr, "%s.%d: (config) %s - done\n", __FILE__, __LINE__, filename);
 #endif
 	filename = old_fn;
-	return 0;
+	return ret;
 }
 
 mconfig *mconfig_init() {
@@ -955,7 +960,7 @@ mconfig *mconfig_init() {
 #endif	
 
 	conf->cmdlineoptions = mlist_init();
-
+	
 	return conf;
 }
 
@@ -1032,7 +1037,7 @@ int mconfig_free(mconfig *conf) {
 	mlist_free(conf->cmdlineoptions);
 
 	mhash_free(conf->variables);
-
+	
 	free(conf->configfile);
 	free(conf->version);
 
