@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mdatatypes.c,v 1.67 2003/02/24 16:54:54 ostborn Exp $
+** $Id: mdatatypes.c,v 1.68 2003/05/30 20:41:55 miham Exp $
 */
 
 #include <stdio.h>
@@ -51,6 +51,7 @@
 #include "datatypes/query/datatype.h"
 #include "datatypes/location/datatype.h"
 #include "datatypes/string/datatype.h"
+#include "datatypes/ipplwatch/datatype.h"
 
 #define M_DEBUG_SAX_ENTRY 0
 #define M_DEBUG_SAX_DISPATCH 0
@@ -70,6 +71,7 @@ const key_map key_mapping[] = {
 	{ M_DATA_TYPE_VISIT,      "type_visit" },
 	{ M_DATA_TYPE_SUBLIST,    "type_sublist" },
 	{ M_DATA_TYPE_LOCATION,   "type_location" },
+	{ M_DATA_TYPE_IPPLWATCH,  "type_ipplwatch" },
 
 	/* 0.7.x */
 	{ M_DATA_TYPE_COUNT,      "count" },
@@ -166,6 +168,7 @@ void mdata_free(mdata *data) {
 	case M_DATA_TYPE_QUERY:    mdata_Query_free(data); break;
 	case M_DATA_TYPE_LOCATION: mdata_Location_free(data); break;
 	case M_DATA_TYPE_STRING:   mdata_String_free(data); break;
+	case M_DATA_TYPE_IPPLWATCH:	mdata_IpplWatch_free(data); break;
 		
 	case M_DATA_TYPE_UNSET:
 		fprintf(stderr, "%s.%d: can't %s unset datatype\n", __FILE__, __LINE__, "free");
@@ -236,6 +239,7 @@ int mdata_datatype_to_xml(gzFile *fd, mdata *data) {
 	case M_DATA_TYPE_VISIT:      return mdata_Visit_to_xml(fd, data);
 	case M_DATA_TYPE_SUBLIST:    return mdata_SubList_to_xml(fd, data);
 	case M_DATA_TYPE_LOCATION:   return mdata_Location_to_xml(fd, data);
+	case M_DATA_TYPE_IPPLWATCH:  return mdata_IpplWatch_to_xml(fd, data);
 		
 	case M_DATA_TYPE_UNSET:
 		fprintf(stderr, "%s.%d: can't %s unset datatype\n", __FILE__, __LINE__, "write");
@@ -257,6 +261,7 @@ mdata *mdata_datatype_init(int type) {
 	case M_DATA_TYPE_VISIT:      return mdata_Visit_init();
 	case M_DATA_TYPE_SUBLIST:    return mdata_SubList_init();
 	case M_DATA_TYPE_LOCATION:   return mdata_Location_init();
+	case M_DATA_TYPE_IPPLWATCH:  return mdata_IpplWatch_init();
 		
 	case M_DATA_TYPE_UNSET:
 		fprintf(stderr, "%s.%d: can't %s unset datatype\n", __FILE__, __LINE__, "init");
@@ -351,6 +356,10 @@ mdata_append_return mdata_append(mdata *dst, mdata *src) {
 		case M_DATA_TYPE_LOCATION:
 			ret = mdata_Location_append(dst, src);
 			break;
+		case M_DATA_TYPE_IPPLWATCH:
+			ret = mdata_IpplWatch_append(dst, src);
+			break;
+
 		case M_DATA_TYPE_UNSET:
 			fprintf(stderr, "%s.%d: can't %s unset datatype\n", __FILE__, __LINE__, "append");
 			break;
@@ -409,6 +418,9 @@ mdata *mdata_copy(mdata *src) {
 		case M_DATA_TYPE_NETMASK:
 			dst = mdata_Netmask_copy(src);
 			break;
+		case M_DATA_TYPE_IPPLWATCH:
+			dst = mdata_IpplWatch_copy(src);
+			break;
 		
 		case M_DATA_TYPE_LOCATION:
 			dst = mdata_Location_copy(src);
@@ -473,6 +485,11 @@ int mdata_read(void *user_data, m_tag tagtype, const xmlChar *value, const xmlCh
 		if (mdata_Location_from_xml(user_data, tagtype, value, attrs))
 			return -1;
 		break;
+	case M_DATA_TYPE_IPPLWATCH:
+		if (mdata_IpplWatch_from_xml(user_data, tagtype, value, attrs))
+			return -1;
+		break;
+
 	case M_DATA_TYPE_UNSET:
 		M_DEBUG1(M_DEBUG_LEVEL_ERRORS, M_DEBUG_SECTION_INIT, M_DEBUG_LEVEL_ERRORS,
 			 "can't %s unset datatype\n",
@@ -574,7 +591,7 @@ int mdata_set_count(mdata *data, int count) {
 }
 
 /**
- * transform a xmlleaf to the internals strutures
+ * transform a xmlleaf to the internals structures
  *
  * @param dest destination
  * @param type type of the destination
