@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mdatatypes.h,v 1.49 2003/01/06 10:52:24 ostborn Exp $
+** $Id: mdatatypes.h,v 1.51 2003/05/30 20:42:17 miham Exp $
 */
 
 #ifndef _M_DATATYPES_H_
@@ -72,6 +72,10 @@ typedef enum {
 	M_DATA_NOT_APPENDED	= 1
 } mdata_append_return;
 
+typedef enum {
+	M_DATA_UNSET, M_DATA_HOST, M_DATA_PORT
+} mdata_ipplwatch_type;
+
 typedef enum {
 	M_DATA_FIELDTYPE_UNSET,	M_DATA_FIELDTYPE_HASH,                               /* 0 */
 		M_DATA_FIELDTYPE_LONG, M_DATA_FIELDTYPE_LIST,                        /* 2 */
@@ -85,7 +89,7 @@ typedef enum {
 		M_DATA_TYPE_STATE, M_DATA_TYPE_QUERY, M_DATA_TYPE_MATCH,             /* 17 */
 		M_DATA_TYPE_RECORD, M_DATA_TYPE_SUBLIST, M_DATA_TYPE_SPLIT,          /* 20 */
 		M_DATA_TYPE_NETMASK, M_DATA_TYPE_PLUGIN, M_DATA_TYPE_MAILHIST,       /* 23 */
-		M_DATA_TYPE_LOCATION                                                 /* 26 */
+		M_DATA_TYPE_LOCATION, M_DATA_TYPE_IPPLWATCH                          /* 26 */
 
 } mdata_field_type;
 
@@ -160,7 +164,7 @@ typedef struct {
 } data_BrokenLink;
 
 /**
-	carries the incomming and outgoing traffic for one station
+	carries the incoming and outgoing traffic for one station
 	( host, network, router, ...)
 
 	key	: name (ip, phonenumber)
@@ -199,6 +203,18 @@ typedef struct {
 	char 		*useragent;
 } data_Visit;
 
+typedef struct {
+	time_t	timestamp;
+	char	*data;
+	long	count;
+} mdata_ipplwatchelement;
+
+typedef struct {
+	mdata_ipplwatchelement	**watches;
+	mdata_ipplwatch_type	type;
+	int			count;
+} data_IpplWatch;
+
 typedef struct {
 	unsigned long	hits;
 	unsigned long	files;
@@ -306,7 +322,7 @@ typedef struct {
 		data_Visited	visited;
 		data_BrokenLink	brokenlink;
 		data_Traffic	* traffic;
-		data_VisitElement visitelem;
+		data_VisitElement	visitelem;
 		data_Visit	* visit;
 		data_History    * hist;
 		data_String	string;
@@ -320,7 +336,8 @@ typedef struct {
 #ifdef HAVE_LIBADNS
 		data_Query	query;
 #endif
-		data_Location   *location;
+		data_Location	* location;
+		data_IpplWatch	* ipplwatch;
 	} data;
 } mdata;
 
@@ -351,6 +368,8 @@ int     mdata_is_grouped(mdata *data);
 int     mdata_get_datatype_from_key(const char *key);
 int     mdata_get_key_type(const mdata *data);
 
+mdata  *mdata_datatype_init( int );
+
 const char *mdata_get_key(mdata *data, void *state);
 
 #endif
