@@ -2,7 +2,7 @@
 ** Modular Logfile Analyzer
 ** Copyright 2000 Jan Kneschke <jan@kneschke.de>
 **
-** Homepage: http://www.kneschke.de/projekte/modlogan
+** Homepage: http://www.modlogan.org
 **
 
     This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mlocale.h,v 1.11 2001/08/17 22:22:32 jk Exp $
+** $Id: mlocale.h,v 1.14 2003/01/06 10:56:13 ostborn Exp $
 */
 
 #ifndef _M_LOCALE_H_
@@ -36,13 +36,13 @@
 #include <locale.h>
 #define _(String) gettext(String)
 #else
-#define _(String) String 
+#define _(String) String
 #endif
 
 int init_locale(mconfig *conf);
 char *mhttpcodes(int status);
-long long isondx(char *str);
-char *misoname(char *str);
+long long isondx(const char *str);
+char *misoname(const char *str);
 
 #define M_RESOLV_UNKNOWN_ERROR	-1
 #define M_RESOLV_UNRESOLVED	-2
