@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mrecord.c,v 1.28 2003/04/18 18:22:46 ostborn Exp $
+** $Id: mrecord.c,v 1.32 2003/07/18 11:39:16 ostborn Exp $
 */
 
 #include <stdlib.h>
@@ -270,6 +270,9 @@ void mrecord_free_traffic(mlogrec_traffic *record) {
 		case M_RECORD_TYPE_TRAFFIC_IPCHAINS:
 			mrecord_free_traffic_ipchains(record->ext);
 			break;
+		case M_RECORD_TYPE_TRAFFIC_IPPL:
+			mrecord_free_traffic_ippl(record->ext);
+			break;
 		default:
 			fprintf(stderr, "%s.%d: Unknown record type: %d\n", __FILE__, __LINE__, record->ext_type);
 		}
@@ -287,7 +290,7 @@ mlogrec_traffic *mrecord_init_traffic() {
 	if (record != NULL) {
 		record->src		= NULL;
 		record->dst		= NULL;
-		record->xfer_incomming	= 0;
+		record->xfer_incoming	= 0;
 		record->xfer_outgoing	= 0;
 
 		record->ext = NULL;
@@ -414,6 +417,21 @@ void mrecord_free_traffic_ipchains(mlogrec_traffic_ipchains *record) {
 	free(record);
 }
 
+void mrecord_free_traffic_ippl(mlogrec_traffic_ippl *record) {
+	if (!record) return;
+
+	record->src_port	= 0;
+	record->dst_port	= 0;
+	record->conn_state	= M_RECORD_IPPL_CONNSTATE_UNSET;
+	record->prototype	= M_RECORD_IPPL_PROTOCOL_UNSET;
+	record->has_ipopts	= 0;
+	if (record->remident)	free(record->remident);
+	if (record->remhost)	free(record->remhost);
+	if (record->protoname)	free(record->protoname);
+
+	free(record);
+}
+
 mlogrec_traffic_ipchains *mrecord_init_traffic_ipchains() {
 	mlogrec_traffic_ipchains *record = malloc(sizeof(mlogrec_traffic_ipchains));
 
@@ -431,6 +449,23 @@ mlogrec_traffic_ipchains *mrecord_init_traffic_ipchains() {
 	return record;
 }
 
+mlogrec_traffic_ippl *mrecord_init_traffic_ippl() {
+	mlogrec_traffic_ippl *record = malloc(sizeof(mlogrec_traffic_ippl));
+
+	if (record != NULL) {
+		record->protoname	= NULL;
+		record->prototype	= M_RECORD_IPPL_PROTOCOL_UNSET;
+		record->has_ipopts	= 0;
+		record->src_port	= 0;
+		record->dst_port	= 0;
+		record->conn_state	= M_RECORD_IPPL_CONNSTATE_UNSET;
+		record->remident	= NULL;
+		record->remhost		= NULL;
+	}
+
+	return record;
+}
+
 
 void mrecord_free_mail(mlogrec_mail *record) {
 	if (!record) return;
@@ -450,23 +485,14 @@ void mrecord_free_mail(mlogrec_mail *record) {
 
 	if (record->receipient)		free(record->receipient);
 	if (record->sender)		free(record->sender);
+	if (record->status_text)	free(record->status_text);
 
 	free(record);
 }
 
 mlogrec_mail *mrecord_init_mail() {
 	mlogrec_mail *record = malloc(sizeof(mlogrec_mail));
-
-	if (record != NULL) {
-		record->receipient	= NULL;
-		record->sender        	= NULL;
-		record->duration        = 0;
-		record->bytes_out	= 0;
-		record->bytes_in	= 0;
-
-		record->ext = NULL;
-		record->ext_type = 0;
-	}
+	memset(record, 0, sizeof(mlogrec_mail));
 
 	return record;
 }
@@ -480,16 +506,7 @@ void mrecord_free_mail_qmail_status (mlogrec_mail_qmail_status *record) {
 
 mlogrec_mail_qmail_status *mrecord_init_mail_qmail_status () {
 	mlogrec_mail_qmail_status  *record = malloc(sizeof(mlogrec_mail_qmail_status));
-
-	if (record != NULL) {
-		record->local_cur	= 0;
-		record->local_max	= 0;
-		record->remote_cur	= 0;
-		record->remote_max	= 0;
-
-		record->queue_cur	= 0;
-		record->deliver_cur	= 0;
-	}
+	memset(record, 0, sizeof(mlogrec_mail_qmail_status));
 
 	return record;
 }
@@ -698,6 +715,22 @@ int mrecord_copy_traffic_flow(mlogrec_traffic_flow *dst, mlogrec_traffic_flow *s
 	return 0;
 }
 
+int mrecord_copy_traffic_ippl(mlogrec_traffic_ippl *dst, mlogrec_traffic_ippl *src) {
+	if (!dst) return -1;
+	if (!src) return -1;
+
+	dst->prototype 	= src->prototype;
+	dst->src_port 	= src->src_port;
+	dst->dst_port 	= src->dst_port;
+	dst->conn_state	= src->conn_state;
+	dst->has_ipopts	= src->has_ipopts;
+	dst->remident	= src->remident ? strdup(src->remident) : NULL;
+	dst->remhost	= src->remhost ? strdup(src->remhost) : NULL;
+	dst->protoname	= src->protoname ? strdup(src->protoname) : NULL;
+	
+	return 0;
+}
+
 int mrecord_copy_traffic(mlogrec_traffic *dst, mlogrec_traffic *src) {
 	if (!dst) return -1;
 	if (!src) return -1;
@@ -712,7 +745,7 @@ int mrecord_copy_traffic(mlogrec_traffic *dst, mlogrec_traffic *src) {
 	FIELD_CPY(dst);
 #undef FIELD_CPY
 
-	dst->xfer_incomming = src->xfer_incomming;
+	dst->xfer_incoming = src->xfer_incoming;
 	dst->xfer_outgoing = src->xfer_outgoing;
 	dst->ext_type = src->ext_type;
 
@@ -722,6 +755,11 @@ int mrecord_copy_traffic(mlogrec_traffic *dst, mlogrec_traffic *src) {
 
 			mrecord_copy_traffic_flow(dst->ext, src->ext);
 			break;
+		case M_RECORD_TYPE_TRAFFIC_IPPL :
+			dst->ext = mrecord_init_traffic_ippl();
+
+			mrecord_copy_traffic_ippl(dst->ext, src->ext);
+			break;
 		case M_RECORD_TYPE_TRAFFIC_UNSET:
 			break;
 		default:
