@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mstate.c,v 1.65 2002/12/30 11:09:43 ostborn Exp $
+** $Id: mstate.c,v 1.66 2003/05/30 20:52:20 miham Exp $
 */
 
 #include <stdlib.h>
@@ -83,6 +83,9 @@ void mstate_free(mstate *state) {
 		case M_STATE_TYPE_TRAFFIC:
 			mstate_free_traffic(state->ext);
 			break;
+		case M_STATE_TYPE_IPPL:
+			mstate_free_ippl(state->ext);
+			break;
 		case M_STATE_TYPE_MAIL:
 			mstate_free_mail(state->ext);
 			break;
@@ -299,6 +302,45 @@ void mstate_free_traffic(mstate_traffic *state) {
 	free(state);
 }
 
+mstate_ippl *mstate_init_ippl() {
+	mstate_ippl *state = malloc(sizeof(mstate_ippl));
+	assert(state);
+
+	state->source_ips 	= mhash_init( 128 );
+	state->destination_ips 	= mhash_init( 128 );
+	state->source_ports 	= mhash_init( 128 );
+	state->destination_ports 	= mhash_init( 128 );
+
+	state->remote_idents 	= mhash_init( 32 );
+
+	state->protocol_names	= mhash_init( 64 );
+
+	state->icmp_params 	= mhash_init( 16 );
+
+	state->watched_shosts	= mhash_init( 128 );
+	state->watched_dports	= mhash_init( 128 );
+
+	return state;
+}
+
+void mstate_free_ippl( mstate_ippl *state) {
+	if (!state) return;
+
+	mhash_free(state->source_ips);
+	mhash_free(state->destination_ips);
+	mhash_free(state->source_ports);
+	mhash_free(state->destination_ports);
+	mhash_free(state->remote_idents);
+	mhash_free(state->protocol_names);
+
+	mhash_free(state->icmp_params);
+
+	mhash_free(state->watched_shosts);
+	mhash_free(state->watched_dports);
+	
+	free(state);
+}
+
 int mhash_write(gzFile *fd, mhash *h) {
 	int i;
 
@@ -525,6 +567,10 @@ int mstate_write_mail (mconfig *conf, mstate_mail *state, gzFile *fd) {
 	return 0;
 }
 
+int mstate_write_ippl(mconfig *conf, mstate_ippl *state, gzFile *fd) {
+	return 0;
+}
+
 int mstate_write_telecom (mconfig *conf, mstate_telecom *state, gzFile *fd) {
 	return 0;
 }
@@ -645,6 +691,9 @@ int mstate_write (mconfig *conf, mstate *state, int _add_month, char *subpath) {
 		case M_STATE_TYPE_TELECOM:
 			mstate_write_telecom(conf, state->ext, fd);
 			break;
+		case M_STATE_TYPE_IPPL:
+			mstate_write_ippl(conf, state->ext, fd);
+			break;
 		case M_STATE_TYPE_TRAFFIC:
 			mstate_write_traffic(conf, state->ext, fd);
 			break;
