@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mstate.h,v 1.33 2002/12/15 18:33:59 ostborn Exp $
+** $Id: mstate.h,v 1.34 2003/05/30 20:52:20 miham Exp $
 */
 
 #ifndef _M_STATE_H_
@@ -36,7 +36,8 @@
 
 enum { M_STATE_TYPE_UNSET, M_STATE_TYPE_WEB,
 		M_STATE_TYPE_TELECOM, M_STATE_TYPE_GLOBAL,
-		M_STATE_TYPE_TRAFFIC, M_STATE_TYPE_MAIL
+		M_STATE_TYPE_TRAFFIC, M_STATE_TYPE_MAIL,
+		M_STATE_TYPE_IPPL
 };
 
 #define M_STATE_SECTION_WEB	"sec_web"
@@ -94,6 +95,13 @@ enum { M_STATE_TYPE_UNSET, M_STATE_TYPE_WEB,
 #define M_STATE_TELECOM_HOURS		"telecom_hours"
 #define M_STATE_TELECOM_DAYS		"telecom_days"
 
+#define M_STATE_IPPL_SRC_IP		"ippl_src_ip"
+#define M_STATE_IPPL_DST_IP		"ippl_dst_ip"
+#define M_STATE_IPPL_SRC_PORTS		"ippl_src_ports"
+#define M_STATE_IPPL_DST_PORTS		"ippl_dst_ports"
+#define M_STATE_IPPL_REMIDENTS		"ippl_remident"
+#define M_STATE_IPPL_PROTOCOLS		"ippl_protocols"
+
 #define M_STATE_WRITE_DEFAULT	0
 #define M_STATE_WRITE_BY_MONTH	1
 
@@ -170,6 +178,45 @@ typedef struct {
 	mhash *internal;
 } mstate_traffic;
 
+typedef struct {
+	long	packets;
+	long	hosts;
+	long	ports;
+	long	portscannum;
+} marray_ippl;
+
+typedef struct {
+	long	icmp;
+	long	tcp;
+	long	udp;
+	long	other;
+} marray_ippl_protocol;
+
+typedef struct {
+	long	has_ipopts;
+	long	has_no_ipopts;
+} marray_ippl_ipopts;
+
+typedef struct {
+	mhash	*source_ips;
+	mhash	*destination_ips;
+	mhash	*source_ports;
+	mhash	*destination_ports;
+
+	mhash	*watched_shosts;
+	mhash	*watched_dports;
+	
+	mhash	*remote_idents;
+	mhash	*protocol_names;
+	marray_ippl_protocol	protocols;
+	marray_ippl_ipopts	ipopts;
+
+	mhash	*icmp_params;
+	
+	marray_ippl	hours[24];
+	marray_ippl	days[31];
+} mstate_ippl;
+
 typedef struct {
 	long incoming_mails;
 	long outgoing_mails;
@@ -209,12 +256,14 @@ mstate *mstate_init();
 mstate_web *mstate_init_web();
 mstate_telecom *mstate_init_telecom();
 mstate_traffic *mstate_init_traffic();
+mstate_ippl *mstate_init_ippl();
 mstate_mail *mstate_init_mail();
 
 void mstate_free(mstate *state);
 void mstate_free_web(mstate_web *state);
 void mstate_free_telecom(mstate_telecom *state);
 void mstate_free_traffic(mstate_traffic *state);
+void mstate_free_ippl(mstate_ippl *state);
 void mstate_free_mail(mstate_mail *state);
 
 int mstate_read (mconfig *conf, mstate *state, int year, int month, char *subpath);
