@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: generate.c,v 1.94 2003/01/06 11:14:16 ostborn Exp $
+** $Id: generate.c,v 1.97 2003/07/31 23:55:47 ostborn Exp $
 */
 
 #include <libintl.h>
@@ -705,6 +705,7 @@ static void file_start(FILE *f, mconfig *ext_conf, time_t timestamp) {
 	config_output *conf = ext_conf->plugin_conf;
 
 	if (include_file(f, conf->html_header, "page header")) {
+		char *tmp;
 		fprintf(f, "<?xml version=\"1.0\" encoding=\"%s\"?>\n"
 			"<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"DTD/xhtml1-transitional.dtd\">\n"
 			"<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"%s\" lang=\"%s\">\n\n"
@@ -723,7 +724,10 @@ static void file_start(FILE *f, mconfig *ext_conf, time_t timestamp) {
 			conf->cont_charset,
 			conf->cont_language);
 
-		fprintf(f, "<h1>%s %s</h1>\n", _("Statistics for"), conf->hostname);
+		tmp = malloc( strlen( _("Statistics for %1$s") ) - 3 + strlen( conf->hostname ) );
+		sprintf( tmp, _("Statistics for %1$s"), conf->hostname );
+		fprintf(f, "<h1>%s</h1>\n", tmp );
+		free(tmp);
 		if (timestamp != 0) {
 			t = timestamp;
 			_tm = localtime(&t);
@@ -769,7 +773,7 @@ static void file_end(FILE *f, mconfig *ext_conf) {
 				"alt=\"Valid XHTML 1.0!\" height=\"31\" width=\"88\" align=\"right\" />\n"
 				"</a>\n"
 				"<a href=\"http://jigsaw.w3.org/css-validator/check/referer/\">\n"
-				" <img border=\"0\" width=\"88\" height=\"31\""
+				" <img border=\"0\" width=\"88\" height=\"31\" "
 				"src=\"http://jigsaw.w3.org/css-validator/images/vcss.gif\" "
 				"alt=\"Valid CSS!\" align=\"right\" />\n"
 				"</a>");
@@ -787,6 +791,7 @@ static void file_start_index(FILE *f, mconfig *ext_conf, time_t timestamp) {
 	config_output *conf = ext_conf->plugin_conf;
 
 	if (include_file(f, conf->html_header, "page header")) {
+		char *tmp;
 		fprintf(f, "<?xml version=\"1.0\" encoding=\"%s\"?>\n"
 			"<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"DTD/xhtml1-transitional.dtd\">\n"
 			"<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"%s\" lang=\"%s\">\n\n"
@@ -805,7 +810,10 @@ static void file_start_index(FILE *f, mconfig *ext_conf, time_t timestamp) {
 			conf->cont_charset,
 			conf->cont_language);
 
-		fprintf(f, "<h1>%s %s</h1>\n", _("Statistics for"), conf->hostname);
+		tmp = malloc( strlen( _("Statistics for %1$s") ) - 3 + strlen( conf->hostname ) );
+		sprintf( tmp, _("Statistics for %1$s"), conf->hostname );
+		fprintf(f, "<h1>%s</h1>\n", tmp );
+		free(tmp);
 		if (timestamp != 0) {
 			t = timestamp;
 			_tm = localtime(&t);
@@ -850,7 +858,7 @@ static void file_end_index(FILE *f, mconfig *ext_conf) {
 				"alt=\"Valid XHTML 1.0!\" height=\"31\" width=\"88\" align=\"right\" />\n"
 				"</a>\n"
 				"<a href=\"http://jigsaw.w3.org/css-validator/check/referer/\">\n"
-				" <img border=\"0\" width=\"88\" height=\"31\""
+				" <img border=\"0\" width=\"88\" height=\"31\" "
 				"src=\"http://jigsaw.w3.org/css-validator/images/vcss.gif\" "
 				"alt=\"Valid CSS!\" align=\"right\" />\n"
 				"</a>");
@@ -860,15 +868,19 @@ static void file_end_index(FILE *f, mconfig *ext_conf) {
 	}
 }
 
+//                     maximum   act_count  product
 char *table_header(int maxcount, int count, const char *str) {
 	static char trans_buf[255];
-
-	snprintf(trans_buf, sizeof(trans_buf)-1, "%d %s %d %s",
-		 (maxcount > count) || (maxcount < 0) ? count : maxcount,
-		 _("of"), count, str);
+	// <maxcount> of <count> <str>
+	// %1$d - maxcount
+	// %2$d - count
+	// %3$s - str
+	// Order is replaceable..
+	snprintf( trans_buf, sizeof( trans_buf ) - 1, _("%1$d of %2$d %3$s" ), 
+						(maxcount > count) || (maxcount < 0) ? count : maxcount,
+					  count, str);
 
 	return trans_buf;
-
 }
 
 #define	M_TYPE_REPORT	1
@@ -1402,7 +1414,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 	reports_def reports[] = {
 		/* 0 */
 		  /* id             data  max. entry to show  title */
-		{ M_REPORT_REQ_URL, NULL, conf->max_req_urls, _("Requested URL's"),
+		{ M_REPORT_REQ_URL, NULL, conf->max_req_urls, _("from Requested URL's"),
 			/* options */
 			HIGHLIGHT | GROUPING | INDEX | PERCENT | VISITS | VISITS_TRAFFIC,
 				0, /* show graph */
@@ -1416,7 +1428,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 1 */
-		{ M_REPORT_REF_URL, NULL, conf->max_ref_urls, _("Referring URL's"),
+		{ M_REPORT_REF_URL, NULL, conf->max_ref_urls, _("from Referring URL's"),
 			HIGHLIGHT | GROUPING | INDEX | PERCENT,
 				0,
 				NULL,
@@ -1429,7 +1441,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 2 */
-		{ M_REPORT_VIEW_DURATION, NULL, conf->max_req_urls, _("View Durations"),
+		{ M_REPORT_VIEW_DURATION, NULL, conf->max_req_urls, _("from View Durations"),
 			HIGHLIGHT | GROUPING | INDEX | PERCENT | VIEW_DURATION,
 				0,
 				NULL,
@@ -1442,7 +1454,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 3 */
-		{ M_REPORT_OS, NULL, conf->max_os, _("Used Operating Systems"),
+		{ M_REPORT_OS, NULL, conf->max_os, _("from Used Operating Systems"),
 			GROUPING | VISITS | INDEX | PERCENT,
 				0,
 				NULL,
@@ -1456,7 +1468,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 4 */
-		{ M_REPORT_HOSTS, NULL, conf->max_hosts, _("Hosts"),
+		{ M_REPORT_HOSTS, NULL, conf->max_hosts, _("from Hosts"),
 			GROUPING | INDEX | VISITS | PERCENT,
 				0,
 				NULL,
@@ -1469,7 +1481,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 5 */
-		{ M_REPORT_ENTRY_PAGES, NULL, conf->max_entry_pages, _("Entry Pages"),
+		{ M_REPORT_ENTRY_PAGES, NULL, conf->max_entry_pages, _("from Entry Pages"),
 			HIGHLIGHT | INDEX | PERCENT,
 				0,
 				NULL,
@@ -1482,7 +1494,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 6 */
-		{ M_REPORT_EXIT_PAGES, NULL, conf->max_exit_pages, _("Exit Pages"),
+		{ M_REPORT_EXIT_PAGES, NULL, conf->max_exit_pages, _("from Exit Pages"),
 			HIGHLIGHT | INDEX | PERCENT,
 				0,
 				NULL,
@@ -1495,7 +1507,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 7 */
-		{ M_REPORT_INDEXED, NULL, conf->max_indexed_pages, _("Indexed Pages"),
+		{ M_REPORT_INDEXED, NULL, conf->max_indexed_pages, _("from Indexed Pages"),
 			HIGHLIGHT | INDEX | PERCENT,
 				0,
 				NULL,
@@ -1508,7 +1520,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 8 */
-		{ M_REPORT_USERAGENT, NULL, conf->max_ua, _("Used Browsers"),
+		{ M_REPORT_USERAGENT, NULL, conf->max_ua, _("from Used Browsers"),
 			GROUPING | VISITS | INDEX | PERCENT,
 				0,
 				NULL,
@@ -1521,7 +1533,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 9 */
-		{ M_REPORT_REQ_PROT, NULL, conf->max_req_prot, _("Used Request Protocol"),
+		{ M_REPORT_REQ_PROT, NULL, conf->max_req_prot, _("from Used Request Protocol"),
 			INDEX | PERCENT,
 				0,
 				NULL,
@@ -1534,7 +1546,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 10 */
-		{ M_REPORT_REQ_METH, NULL, conf->max_req_meth, _("Used Request Method"),
+		{ M_REPORT_REQ_METH, NULL, conf->max_req_meth, _("from Used Request Method"),
 			INDEX | PERCENT,
 				0,
 				NULL,
@@ -1547,7 +1559,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 11 */
-		{ M_REPORT_ROBOTS, NULL, conf->max_robots, _("Robots"),
+		{ M_REPORT_ROBOTS, NULL, conf->max_robots, _("from Robots"),
 			INDEX | PERCENT,
 				0,
 				NULL,
@@ -1560,7 +1572,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 12 */
-		{ M_REPORT_BOOKMARKS, NULL, conf->max_bookmarks, _("Bookmarked Pages"),
+		{ M_REPORT_BOOKMARKS, NULL, conf->max_bookmarks, _("from Bookmarked Pages"),
 			HIGHLIGHT | INDEX | PERCENT,
 				0,
 				NULL,
@@ -1573,7 +1585,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 13 */
-		{ M_REPORT_BROKEN_LINKS, NULL, conf->max_broken_links, _("Missing File / Broken Link"),
+		{ M_REPORT_BROKEN_LINKS, NULL, conf->max_broken_links, _("from Missing File / Broken Link"),
 			GROUPING | INDEX | BROKEN_LINK | PERCENT,
 				0,
 				NULL,
@@ -1586,7 +1598,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 14 */
-		{ M_REPORT_INTERNAL_ERROR, NULL, conf->max_internal_errors, _("Internal Errors"),
+		{ M_REPORT_INTERNAL_ERROR, NULL, conf->max_internal_errors, _("from Internal Errors"),
 			INDEX | BROKEN_LINK,
 				0,
 				NULL,
@@ -1599,7 +1611,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 15 */
-		{ M_REPORT_SEARCH_STRINGS, NULL, conf->max_search_strings, _("SearchStrings"),
+		{ M_REPORT_SEARCH_STRINGS, NULL, conf->max_search_strings, _("from SearchStrings"),
 			INDEX | PERCENT | GROUPING,
 				0,
 				NULL,
@@ -1612,7 +1624,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 16 */
-		{ M_REPORT_SEARCH_ENGINE, NULL, conf->max_search_engines, _("SearchEngines"),
+		{ M_REPORT_SEARCH_ENGINE, NULL, conf->max_search_engines, _("from SearchEngines"),
 			HIGHLIGHT | GROUPING | INDEX | PERCENT,
 				0,
 				NULL,
@@ -1626,7 +1638,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 17 */
-		{ M_REPORT_EXTENSION, NULL, conf->max_extensions, _("Extensions"),
+		{ M_REPORT_EXTENSION, NULL, conf->max_extensions, _("from Extensions"),
 			HIGHLIGHT | GROUPING |INDEX | PERCENT | VISITS | VISITS_TRAFFIC,
 				1,
 				mplugin_modlogan_create_pic_ext,
@@ -1639,7 +1651,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 18 */
-		{ M_REPORT_VISIT_DURATION, NULL, conf->max_visit_durations, _("Time Per Visit"),
+		{ M_REPORT_VISIT_DURATION, NULL, conf->max_visit_durations, _("from Time Per Visit"),
 			INDEX | PERCENT | SORT_BY_KEY,
 				1,
 				mplugin_modlogan_create_pic_vd,
@@ -1652,7 +1664,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 19 */
-		{ M_REPORT_VISIT_PATH_LENGTH, NULL, conf->max_visit_path_lengths, _("Visit Path Length"),
+		{ M_REPORT_VISIT_PATH_LENGTH, NULL, conf->max_visit_path_lengths, _("from Visit Path Length"),
 			INDEX | PERCENT | SORT_BY_KEY,
 				1,
 				mplugin_modlogan_create_pic_vpl,
@@ -1666,7 +1678,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 20 */
-		{ M_REPORT_COUNTRIES, NULL, conf->max_countries, _("Countries"),
+		{ M_REPORT_COUNTRIES, NULL, conf->max_countries, _("from Countries"),
 			VISITS | INDEX | PERCENT | RESOLVE_TLD,
 				conf->show_country_graph,
 				mplugin_modlogan_create_pic_countries,
@@ -1679,7 +1691,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 			}
 		},
 		/* 21 */
-		{ M_REPORT_VHOSTS, NULL, conf->max_vhosts, _("Vhosts"),
+		{ M_REPORT_VHOSTS, NULL, conf->max_vhosts, _("from Vhosts"),
 			GROUPING | INDEX | VISITS | PERCENT,
 				conf->show_vhost_graph,
 				mplugin_modlogan_create_pic_vhost,
@@ -1934,7 +1946,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 				table_start(f,
 					    table_header(conf->max_visit_paths,
 							 mhash_count(staweb->visits),
-							 _("Visit Path")),
+							 _("from Visit Path")),
 					    4);
 
 				indent(f, html_indent_depth);
@@ -1970,7 +1982,7 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 				}
 
 				write_report_header(ext_conf, f, sep_sub, sep_report);
-				table_start(f, table_header(conf->max_status_codes, mhash_count(staweb->status_hash),_("Status Code")), 3);
+				table_start(f, table_header(conf->max_status_codes, mhash_count(staweb->status_hash),_("from Status Code")), 3);
 				indent(f, html_indent_depth);
 				fprintf(f,"<tr><th class=\"%s\">%s</th><th>%%</th><th width=\"200\">%s</th></tr>\n",
 					"hits",	_("Hits"),
