@@ -2,7 +2,7 @@
 ** Modular Logfile Analyzer
 ** Copyright 2000 Jan Kneschke <jan@kneschke.de>
 **
-** Homepage: http://www.kneschke.de/projekte/modlogan
+** Homepage: http://www.modlogan.org
 **
 
     This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: generate.h,v 1.4 2001/11/06 10:24:28 ostborn Exp $
+** $Id: generate.h,v 1.6 2002/09/26 13:10:27 ostborn Exp $
 */
 #ifndef _GENERATE_H_
 #define _GENERATE_H_
@@ -30,7 +30,6 @@
 #include "plugin_config.h"
 #include "mhash.h"
 
-char *get_month_string(int m, int tla);
 mhash *get_visit_path_length(mhash *h);
 mhash *get_visit_duration(mhash *h);
 
