@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: pictures_countries.c,v 1.24 2003/01/06 11:14:17 ostborn Exp $
+** $Id: pictures_countries.c,v 1.25 2003/07/29 12:38:37 miham Exp $
 */
 #include <stdio.h>
 #include <stdlib.h>
@@ -88,9 +88,13 @@ char *mplugin_modlogan_create_pic_countries(mconfig *ext_conf, mstate *state) {
 
 	memset(graph, 0, sizeof(mgraph));
 
-	graph->name = malloc(strlen(_("Countries for")) + strlen(get_month_string(state->month,0)) + 4 + 2 + 1);
-	sprintf(graph->name, "%s %s %04d",
-		_("Countries for"),
+  // -5 because -10 + 4 + 1 = -5
+	graph->name = malloc(strlen(_("Countries for %1$s %2$04d")) + 
+                       strlen(get_month_string(state->month,0)) - 5 );  
+                       // %1$s - monthname
+                       // %2$04d - year padded w/ zeroes in 4 digit
+                       // You can change the orders
+	sprintf(graph->name, _("Countries for %1$s %2$04d"),
 		get_month_string(state->month,0),
 		state->year
 		);
