@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: pictures_ext.c,v 1.9 2003/01/06 11:14:17 ostborn Exp $
+** $Id: pictures_ext.c,v 1.10 2003/07/29 12:38:37 miham Exp $
 */
 #include <stdio.h>
 #include <stdlib.h>
@@ -88,9 +88,11 @@ char *mplugin_modlogan_create_pic_ext(mconfig *ext_conf, mstate *state) {
 
 	memset(graph, 0, sizeof(mgraph));
 
-	graph->name = malloc(strlen(_("Extensions for")) + strlen(get_month_string(state->month,0)) + 4 + 2 + 1);
-	sprintf(graph->name, "%s %s %04d",
-		_("Extensions for"),
+	graph->name = malloc(strlen(_("Extensions for %1$s %2$04d")) + 
+			     strlen(get_month_string(state->month,0)) - 5);
+			     // %1$s - month
+			     // %2$04d - year
+	sprintf(graph->name, _("Extensions for %1$s %2$04d"),
 		get_month_string(state->month,0),
 		state->year
 		);
