@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: pictures_month.c,v 1.27 2003/01/06 11:14:17 ostborn Exp $
+** $Id: pictures_month.c,v 1.28 2003/08/01 21:30:01 miham Exp $
 */
 #include <stdio.h>
 #include <stdlib.h>
@@ -75,6 +75,7 @@ char *mplugin_modlogan_create_pic_X_month(mconfig *ext_conf, mlist *history) {
 	rgb_tripple rgb;
 	char int2str[20]; /* 20 is a guess only !! */
 	int x1, y1, x2, y2;
+	char *tmp;
 	config_output *conf = ext_conf->plugin_conf;
 
 
@@ -259,11 +260,12 @@ char *mplugin_modlogan_create_pic_X_month(mconfig *ext_conf, mlist *history) {
 	/* header */
 	x1 = IM_BOX1_X1;
 	y1 = IM_CELLSPACING;
-	gdImageString(im, gdFontSmall, x1, y1, _("Usage summary for "), col_border);
-
-	x1 += strlen(_("Usage summary for ")) * IM_FONT_WIDTH;
-	gdImageString(im, gdFontSmall, x1, y1, conf->hostname, col_border);
+	tmp = malloc( strlen( _("Usage summary for %1$s") ) - 3 + strlen( conf->hostname ) );
+	sprintf( tmp, _("Usage summary for %1$s"), conf->hostname );
+	gdImageString(im, gdFontSmall, x1, y1, tmp, col_border);
 
+	x1 += strlen(tmp) * IM_FONT_WIDTH;
+	free(tmp);
 
 	/* border for BOX1 */
 	gdImageRectangle(im,
