@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: pictures_vd.c,v 1.16 2003/01/06 11:14:17 ostborn Exp $
+** $Id: pictures_vd.c,v 1.17 2003/07/29 12:38:37 miham Exp $
 */
 #include <stdio.h>
 #include <stdlib.h>
@@ -72,18 +72,20 @@ char *mplugin_modlogan_create_pic_vd(mconfig *ext_conf, mstate *state) {
 	mgraph * graph = malloc(sizeof(mgraph));
 	memset(graph, 0, sizeof(mgraph));
 
-	graph->name = malloc(strlen(_("Visit Duration for")) + 1 + 
-			     strlen(get_month_string(state->month,0)) + 1 
-			     + 4 + 1 + strlen(_("(bottom ")) + 
-			     strlen(GRAPH_CUTOFF_TEXT) + strlen(_(", in min)")) + 1);
-	
-	sprintf(graph->name, "%s %s %04d %s%s%s",
-		_("Visit Duration for"),
+  // FIXME: This code has Y10K error :-)
+  // -9 because -14 + 1 + 4 
+  graph->name = malloc( strlen( get_month_string(state->month,0)) - 9 +
+                      strlen( GRAPH_CUTOFF_TEXT ) + 
+                      strlen( _("Visit Duration for %1$s %2$04d (bottom %3$s, in min)")));
+                      // %1$s - monthname
+                      // %2$04d - year, padded w/ 0 in 4 digits
+                      // %3$s - graph cutoff text (95%)
+                      // You can alter the order of the arguments via
+                      // changing the appearence order in the msgstr ..
+	sprintf(graph->name, _("Visit Duration for %1$s %2$04d (bottom %3$s, in min)"),
 		get_month_string(state->month,0),
 		state->year,
-		_("(bottom "),
-		GRAPH_CUTOFF_TEXT,
-		_(", in min)")
+		GRAPH_CUTOFF_TEXT
 		);
 
 	h = get_visit_duration(staweb->visits);
