@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: pictures_vpl.c,v 1.18 2003/01/06 11:14:17 ostborn Exp $
+** $Id: pictures_vpl.c,v 1.20 2003/08/01 21:30:01 miham Exp $
 */
 #include <stdio.h>
 #include <stdlib.h>
@@ -73,14 +73,18 @@ char *mplugin_modlogan_create_pic_vpl(mconfig *ext_conf, mstate *state) {
 	mgraph * graph = malloc(sizeof(mgraph));
 	memset(graph, 0, sizeof(mgraph));
 
-	graph->name = malloc(strlen(_("Visit Path lengths for")) + 1 + strlen(get_month_string(state->month,0)) + 1 + 4 + 1 + strlen(_("(bottom ")) + strlen(GRAPH_CUTOFF_TEXT) + strlen(_(", in pages)")) + 1);
-	sprintf(graph->name, "%s %s %04d %s%s%s",
-		_("Visit Path lengths for"),
+	graph->name = malloc( strlen( get_month_string(state->month,0)) - 9 +
+                      strlen( GRAPH_CUTOFF_TEXT ) +
+                      strlen( _("Visit Path lengths for %1$s %2$04d (bottom %3$s, in pages)")));
+                        // %1$s - monthname
+                        // %2$04d - year, padded w/ 0 in 4 digits
+                        // %3$s - graph cutoff text (95%)
+                        // You can alter the order of the arguments via 
+                        // changing the appearence order in the msgstr ..
+	sprintf(graph->name, _("Visit Path lengths for %1$s %2$04d (bottom %3$s, in pages)"),
 		get_month_string(state->month,0),
 		state->year,
-		_("(bottom "),
-		GRAPH_CUTOFF_TEXT,
-		_(", in pages)")
+		GRAPH_CUTOFF_TEXT
 		);
 
 	h = get_visit_path_length(staweb->visits);
