@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.c,v 1.45 2003/01/06 11:14:17 ostborn Exp $
+** $Id: plugin_config.c,v 1.46 2003/07/18 07:23:56 ostborn Exp $
 */
 
 #include <libintl.h>
@@ -90,7 +90,9 @@ int mplugins_output_modlogan_dlclose(mconfig *ext_conf) {
 	if (conf->html_footer)	free(conf->html_footer);
 	if (conf->assumedprotocol)	free(conf->assumedprotocol);
 	if (conf->hostname)	free(conf->hostname);
-
+	if (conf->cont_language) free(conf->cont_language);
+	if (conf->cont_charset) free(conf->cont_charset);
+	
 	/* Added by Georges 'Melkor' Goncalves <melkor@lords.com>
 	** courtesy of Jan Kneschke
 	*/
