@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: generate.c,v 1.56 2003/04/18 18:43:48 ostborn Exp $
+** $Id: generate.c,v 1.60 2003/08/01 01:25:31 ostborn Exp $
 */
 
 #include <libintl.h>
@@ -74,44 +74,47 @@ char * generate_output_link (mconfig *ext_conf, int year, int month, const char
 
 	/* huge overkill, but dawm nice code */
 
-	tmpl = tmpl_init();
 	sprintf(date, "%04d%02d",
 		year,
 		month);
 
-	tmpl_load_string(tmpl,  conf->filename_pattern);
+	if (conf->tmpl_output_link == NULL) {
+		tmpl = tmpl_init();
+		tmpl_load_string(tmpl,  conf->filename_pattern);
+		
+		conf->tmpl_output_link = tmpl;
+	} else {
+		tmpl = conf->tmpl_output_link;
+	}
 	tmpl_set_var(tmpl, "NAME", current);
 	tmpl_set_var(tmpl, "DATE", date);
 
 	if (tmpl_replace(tmpl, conf->tmp_buf)) {
 		tmpl_free(tmpl);
 		
+		conf->tmpl_output_link = NULL;
+		
 		return NULL;
 	}
 
-	tmpl_free(tmpl);
-	
 	fn = strdup(conf->tmp_buf->ptr);
 
 	return fn;
 }
 
-static char * generate_output_filename (mconfig *ext_conf, mstate *state, const char *current) {
+int generate_output_filename (mconfig *ext_conf, mstate *state, const char *current, buffer *output_filename) {
 	char *lnk = generate_output_link(ext_conf, state->year, state->month, current);
-	char *fn;
 	config_output *conf = ext_conf->plugin_conf;
 	
-	if (!lnk) return NULL;
-
-	fn = malloc(strlen(conf->outputdir) + strlen(lnk) + 1 + 2);
-
-	sprintf(fn, "%s/%s",
-		conf->outputdir,
-		lnk);
+	if (!lnk) return -1;
 
+	buffer_strcpy(output_filename, conf->outputdir);
+	buffer_strcat_len(output_filename, "/", 1);
+	buffer_strcat(output_filename, lnk);
+	
 	free(lnk);
 
-	return fn;
+	return 0;
 }
 
 char * generate_template_filename(mconfig *ext_conf, int type) {
@@ -297,6 +300,9 @@ static char * generate_menu (mconfig *ext_conf, mstate *state, const char *curre
 		return NULL;
 	}
 	
+	
+	tmpl_free(tmpl);
+	
 	s = strdup(conf->tmp_buf->ptr);
 
 	return s;
@@ -646,29 +652,20 @@ static int generate_monthly_output(mconfig *ext_conf, mstate *state) {
 		/* replace tags by the actual output */
 		if (0 == tmpl_replace(tmpl, conf->tmp_output)) {
 			/* index-file */
-			char *fn;
 			int fd;
 			
-			fn = generate_output_filename(ext_conf, state, l->data->key);
-
-			if (!fn) {
+			if (-1 == generate_output_filename(ext_conf, state, l->data->key, conf->tmpl_output_filename)) {
 				M_DEBUG1(ext_conf->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_ERRORS,
 					 "no filename for output: %s\n",
 					 l->data->key);
 
 				return -1;
-			} else {
-#if 0
-				fprintf(stdout, "%s.%d: %s\n",
-					__FILE__, __LINE__, fn
-					);
-#endif
 			}
 
-			if ((fd = open(fn, O_WRONLY | O_CREAT | O_TRUNC, 0644)) < 0) {
+			if ((fd = open(conf->tmpl_output_filename->ptr, O_WRONLY | O_CREAT | O_TRUNC, 0644)) < 0) {
 				M_DEBUG2(ext_conf->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_ERRORS,
 					 "opening '%s' failed: %s\n",
-					 fn, strerror(errno));
+					 conf->tmpl_output_filename->ptr, strerror(errno));
 
 				return -1;
 			}
@@ -676,8 +673,6 @@ static int generate_monthly_output(mconfig *ext_conf, mstate *state) {
 			write(fd, conf->tmp_output->ptr, conf->tmp_output->used - 1);
 			
 			close(fd);
-
-			free(fn);
 		}
 		MTIMER_STOP(timer[8]);
 		MTIMER_CALC(timer[8]);
@@ -774,12 +769,9 @@ static int generate_monthly_output(mconfig *ext_conf, mstate *state) {
 		/* replace tags by the actual output */
 		if (0 == tmpl_replace(tmpl, conf->tmp_output)) {
 			/* index-file */
-			char *fn;
 			int fd;
 			
-			fn = generate_output_filename(ext_conf, state, d[i]->key);
-			
-			if (!fn) {
+			if (-1 == generate_output_filename(ext_conf, state, d[i]->key, conf->tmpl_output_filename))  {
 				M_DEBUG1(ext_conf->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_ERRORS,
 					 "no filename for output: %s\n",
 					 d[i]->key);
@@ -787,13 +779,13 @@ static int generate_monthly_output(mconfig *ext_conf, mstate *state) {
 				return -1;
 			}
 			
-			if ((fd = open(fn, O_WRONLY | O_CREAT | O_TRUNC, 0644)) < 0) {
+			if ((fd = open(conf->tmpl_output_filename->ptr, O_WRONLY | O_CREAT | O_TRUNC, 0644)) < 0) {
 				config_output *conf = ext_conf->plugin_conf;
 				char *lnk;
 				
 				lnk = generate_output_link(ext_conf, state->year, state->month, d[i]->key);
 				M_DEBUG2(ext_conf->debug_level, M_DEBUG_SECTION_GENERATING, M_DEBUG_LEVEL_ERRORS,
-					"Can't open File \"%s\" for write. error=%s\n", fn, strerror(errno));
+					"Can't open File \"%s\" for write. error=%s\n", conf->tmpl_output_filename->ptr, strerror(errno));
 				M_DEBUG3(ext_conf->debug_level, M_DEBUG_SECTION_GENERATING, M_DEBUG_LEVEL_ERRORS,
 					"outputdir=\"%s\", lnk=\"%s\", d[i]->key=\"%s\"\n", conf->outputdir, lnk, d[i]->key);
 				free(lnk);
@@ -803,8 +795,6 @@ static int generate_monthly_output(mconfig *ext_conf, mstate *state) {
 				
 				close(fd);
 			}
-
-			free(fn);
 		}
 	}
 
@@ -988,7 +978,7 @@ static int generate_history_output(mconfig *ext_conf, mlist *history) {
 		{ NULL,  NULL }
 	};
 
-	if (history == NULL) return -1;
+	if (history == NULL || history->data == NULL) return -1;
 	
 	/* suffix for the generated statistics page files */
 	sprintf(filename, "%s/%s",
@@ -1096,7 +1086,6 @@ static int generate_history_output(mconfig *ext_conf, mlist *history) {
 			M_DEBUG2(ext_conf->debug_level, M_DEBUG_SECTION_GENERATING, M_DEBUG_LEVEL_ERRORS,
 				 "Can't open File \"%s\" for write. errno=%d\n", filename, errno);
 		} else {
-			
 			write(fd, conf->tmp_output->ptr, conf->tmp_output->used - 1);
 			
 			close(fd);
