@@ -2,7 +2,7 @@
 ** Modular Logfile Analyzer
 ** Copyright 2000 Jan Kneschke <jan@kneschke.de>
 **
-** Homepage: http://www.kneschke.de/projekte/modlogan
+** Homepage: http://www.modlogan.org
 **
 
     This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: generate.h,v 1.4 2001/12/18 23:45:43 ostborn Exp $
+** $Id: generate.h,v 1.7 2002/09/26 13:10:28 ostborn Exp $
 */
 #ifndef _GENERATE_H_
 #define _GENERATE_H_
@@ -31,7 +31,7 @@
 
 enum {M_TMPL_UNSET, M_TMPL_TABLE, M_TMPL_OUTER, M_TMPL_MENU, M_TMPL_INDEX};
 
-char *get_month_string(int m, int tla);
 char * generate_template_filename(mconfig *ext_conf, int type);
+char * generate_output_link (mconfig *ext_conf, int year, int month, const char *current);
 
 #endif
