@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: pictures_countries.c,v 1.13 2003/04/18 18:46:56 ostborn Exp $
+** $Id: pictures_countries.c,v 1.14 2003/07/29 12:38:37 miham Exp $
 */
 #include <stdio.h>
 #include <stdlib.h>
@@ -89,12 +89,12 @@ char *create_pic_countries(mconfig *ext_conf, mstate *state) {
 
 	memset(graph, 0, sizeof(mgraph));
 
-	graph->name = malloc(strlen(_("Countries for")) + strlen(get_month_string(state->month,0)) + 4 + 2 + 1);
-	sprintf(graph->name, "%s %s %04d",
-		_("Countries for"),
-		get_month_string(state->month,0),
-		state->year
-		);
+  graph->name = malloc(strlen(_("Countries for %1$s %2$04d")) +
+                       strlen(get_month_string(state->month,0)) - 5 );
+  sprintf(graph->name, _("Countries for %1$s %2$04d"),
+    get_month_string(state->month,0),
+    state->year
+    );
 
 	graph->max_x = 1;
 	graph->max_z = 0;
@@ -205,12 +205,12 @@ char *create_pic_countries_visits(mconfig *ext_conf, mstate *state) {
 
 	memset(graph, 0, sizeof(mgraph));
 
-	graph->name = malloc(strlen(_("Countries for")) + strlen(get_month_string(state->month,0)) + 4 + 2 + 1);
-	sprintf(graph->name, "%s %s %04d",
-		_("Countries for"),
-		get_month_string(state->month,0),
-		state->year
-		);
+  graph->name = malloc(strlen(_("Countries for %1$s %2$04d")) + 
+                       strlen(get_month_string(state->month,0)) - 5);
+  sprintf(graph->name, _("Countries for %1$s %2$04d"),
+    get_month_string(state->month,0),
+    state->year
+    );
 
 	graph->max_x = 1;
 	graph->max_z = 0;
