@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: pictures_ext.c,v 1.11 2003/04/18 18:46:56 ostborn Exp $
+** $Id: pictures_ext.c,v 1.12 2003/07/29 12:38:37 miham Exp $
 */
 #include <stdio.h>
 #include <stdlib.h>
@@ -89,13 +89,15 @@ char *create_pic_ext(mconfig *ext_conf, mstate *state) {
 
 	memset(graph, 0, sizeof(mgraph));
 
-	graph->name = malloc(strlen(_("Extensions for")) + strlen(get_month_string(state->month,0)) + 4 + 2 + 1);
-	sprintf(graph->name, "%s %s %04d",
-		_("Extensions for"),
-		get_month_string(state->month,0),
-		state->year
-		);
-
+        graph->name = malloc(strlen(_("Extensions for %1$s %2$04d")) +
+                             strlen(get_month_string(state->month,0)) - 5);
+                             // %1$s - month
+                             // %2$04d - year
+        sprintf(graph->name, _("Extensions for %1$s %2$04d"),
+                get_month_string(state->month,0),
+                state->year
+                );
+                            
 	graph->max_x = 1;
 	graph->max_z = 0;
 	l = first;
@@ -212,13 +214,15 @@ char *create_pic_ext_traffic(mconfig *ext_conf, mstate *state) {
 
 	memset(graph, 0, sizeof(mgraph));
 
-	graph->name = malloc(strlen(_("Extensions for")) + strlen(get_month_string(state->month,0)) + 4 + 2 + 1);
-	sprintf(graph->name, "%s %s %04d",
-		_("Extensions for"),
-		get_month_string(state->month,0),
-		state->year
-		);
-
+        graph->name = malloc(strlen(_("Extensions for %1$s %2$04d")) +
+                             strlen(get_month_string(state->month,0)) - 5);
+                             // %1$s - month
+                             // %2$04d - year
+        sprintf(graph->name, _("Extensions for %1$s %2$04d"),
+                get_month_string(state->month,0),
+                state->year
+                );
+                            
 	graph->max_x = 1;
 	graph->max_z = 0;
 	for (l = first; l; l = l->next) {
