@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: pictures_hour.c,v 1.8 2002/10/23 15:05:37 le_zas Exp $
+** $Id: pictures_hour.c,v 1.9 2003/07/29 12:38:37 miham Exp $
 */
 #include <stdio.h>
 #include <stdlib.h>
@@ -63,9 +63,9 @@ char *create_pic_24_hour(mconfig *ext_conf, mstate *state) {
 	mgraph * graph = malloc(sizeof(mgraph));
 	memset(graph, 0, sizeof(mgraph));
 
-	graph->name = malloc(strlen(_("Hourly usage for")) + strlen(get_month_string(state->month,0)) + 4 + 2 + 1);
-	sprintf(graph->name, "%s %s %04d",
-		_("Hourly usage for"),
+	graph->name = malloc(strlen(_("Hourly usage for %1$s %2$04d")) + 
+											 strlen(get_month_string(state->month,0)) - 5 );
+	sprintf(graph->name, _("Hourly usage for %1$s %2$04d"),
 		get_month_string(state->month,0),
 		state->year
 		);
