@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: pictures_vpl.c,v 1.10 2003/01/06 11:18:15 ostborn Exp $
+** $Id: pictures_vpl.c,v 1.11 2003/07/29 12:38:37 miham Exp $
 */
 #include <stdio.h>
 #include <stdlib.h>
@@ -74,15 +74,15 @@ char *create_pic_vpl(mconfig *ext_conf, mstate *state) {
 	mgraph * graph = malloc(sizeof(mgraph));
 	memset(graph, 0, sizeof(mgraph));
 
-	graph->name = malloc(strlen(_("Visit Path lengths for")) + 1 + strlen(get_month_string(state->month,0)) + 1 + 4 + 1 + strlen(_("(bottom ")) + strlen(GRAPH_CUTOFF_TEXT) + strlen(_(", in pages)")) + 1);
-	sprintf(graph->name, "%s %s %04d %s%s%s",
-		_("Visit Path lengths for"),
-		get_month_string(state->month,0),
-		state->year,
-		_("(bottom "),
-		GRAPH_CUTOFF_TEXT,
-		_(", in pages)")
-		);
+  graph->name = malloc( strlen( get_month_string(state->month,0)) - 9 +
+                      strlen( GRAPH_CUTOFF_TEXT ) +
+                      strlen( _("Visit Path lengths for %1$s %2$04d (bottom %3$s, in pages)")));
+
+  sprintf(graph->name, _("Visit Path lengths for %1$s %2$04d (bottom %3$s, in pages)"),
+    get_month_string(state->month,0),
+    state->year,
+    GRAPH_CUTOFF_TEXT
+    );
 
 	h = get_visit_path_length(staweb->visits);
 
