@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.c,v 1.38 2003/04/18 18:46:15 ostborn Exp $
+** $Id: plugin_config.c,v 1.40 2003/08/01 01:25:50 ostborn Exp $
 */
 
 #include <libintl.h>
@@ -79,6 +79,7 @@ int mplugins_output_template_dlinit(mconfig *ext_conf) {
 	
 	conf->tmp_buf = buffer_init();
 	conf->tmp_output = buffer_init();
+	conf->tmpl_output_filename = buffer_init();
 
 	ext_conf->plugin_conf = conf;
 
@@ -90,6 +91,7 @@ int mplugins_output_template_dlclose(mconfig *ext_conf) {
 	
 	buffer_free(conf->tmp_buf);
 	buffer_free(conf->tmp_output);
+	buffer_free(conf->tmpl_output_filename);
 
 	mlist_free(conf->variables);
 	mlist_free(conf->reports);
@@ -104,13 +106,72 @@ int mplugins_output_template_dlclose(mconfig *ext_conf) {
 	/* these pointer are static, but have to die at the end */
 	generate_web_cleanup(ext_conf);
 	generate_mail_cleanup(ext_conf);
+#define CLEAN(x) \
+	if (conf->x) free(conf->x);
+	
+	CLEAN(template_path);
+	CLEAN(template_name);
 
-	if (conf->template_name) free(conf->template_name);
-	if (conf->template_path) free(conf->template_path);
-	if (conf->assumedprotocol) free(conf->assumedprotocol);
-	if (conf->hostname) free(conf->hostname);
-	if (conf->index_filename) free(conf->index_filename);
-	if (conf->filename_pattern) free(conf->filename_pattern);
+	CLEAN(col_pages);
+	CLEAN(col_files);
+	CLEAN(col_visits);
+	CLEAN(col_xfer);
+	CLEAN(col_hits);
+	CLEAN(col_backgnd);
+	CLEAN(col_shadow);
+	CLEAN(col_border);
+	CLEAN(col_foregnd);
+
+	/* Provide flexible classnames */
+	CLEAN(cell_class_title);
+	CLEAN(cell_class_leftheader);
+	CLEAN(cell_class_header);
+	CLEAN(cell_class_rightheader);
+	CLEAN(cell_class_leftline);
+	CLEAN(cell_class_line);
+	CLEAN(cell_class_rightline);
+	CLEAN(cell_class_leftgline);
+	CLEAN(cell_class_gline);
+	CLEAN(cell_class_rightgline);
+	CLEAN(cell_class_leftfooter);
+	CLEAN(cell_class_footer);
+	CLEAN(cell_class_rightfooter);
+	CLEAN(cell_class_lefthline);
+	CLEAN(cell_class_hline);
+	CLEAN(cell_class_righthline);
+
+	/* Provide flexible tagadditions */
+	CLEAN(cell_tags_title);
+	CLEAN(cell_tags_leftheader);
+	CLEAN(cell_tags_header);
+	CLEAN(cell_tags_rightheader);
+	CLEAN(cell_tags_leftline);
+	CLEAN(cell_tags_line);
+	CLEAN(cell_tags_rightline);
+	CLEAN(cell_tags_leftgline);
+	CLEAN(cell_tags_gline);
+	CLEAN(cell_tags_rightgline);
+	CLEAN(cell_tags_leftfooter);
+	CLEAN(cell_tags_footer);
+	CLEAN(cell_tags_rightfooter);
+	CLEAN(cell_tags_lefthline);
+	CLEAN(cell_tags_hline);
+	CLEAN(cell_tags_righthline);
+
+	CLEAN(assumedprotocol);
+	CLEAN(hostname);
+	CLEAN(filename_pattern);
+	CLEAN(index_filename);
+
+	CLEAN(outputdir);
+
+	CLEAN(tmpl_menu);
+	CLEAN(tmpl_outer);
+	CLEAN(tmpl_table);
+	CLEAN(tmpl_index);
+#undef CLEAN
+	
+	if (conf->tmpl_output_link) tmpl_free(conf->tmpl_output_link);
 
 	free(ext_conf->plugin_conf);
 	ext_conf->plugin_conf = NULL;
