@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.h,v 1.21 2003/04/18 18:46:15 ostborn Exp $
+** $Id: plugin_config.h,v 1.22 2003/08/01 01:25:50 ostborn Exp $
 */
 #ifndef _OUTPUT_PLUGIN_CONFIG_H_
 #define _OUTPUT_PLUGIN_CONFIG_H_
@@ -31,6 +31,7 @@
 #include "mlist.h"
 #include "mstate.h"
 #include "mtree.h"
+#include "template.h"
 
 /**
  * data container for the coloums of the tables
@@ -151,6 +152,10 @@ typedef struct {
 	buffer *tmp_buf;
 	buffer *tmp_output;
 	
+	
+	tmpl_main *tmpl_output_link;
+	buffer *tmpl_output_filename;
+	
 	void * old_conf;
 } config_output;
 
