@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: template.c,v 1.21 2003/04/18 18:43:48 ostborn Exp $
+** $Id: template.c,v 1.24 2003/08/01 01:28:27 ostborn Exp $
 */
 
 #include <libintl.h>
@@ -73,15 +73,8 @@ int tmpl_get_line_from_string (tmpl_string *conf) {
 	for (i = 0; *(s + i) != '\n' && *(s + i) != '\0'; i++) ;
 
 	if (*(s + i) == '\n') i++;
-
-	if (i > conf->buf_len) {
-		free(conf->buffer);
-		conf->buf_len = i;
-		conf->buffer = malloc((conf->buf_len + 1) * sizeof(char));
-	}
-
-	strncpy(conf->buffer, s, i);
-	conf->buffer[i] = '\0';
+	
+	buffer_strcpy_len(conf->buffer, s, i);
 
 	conf->str_pos += i;
 
@@ -139,6 +132,8 @@ int tmpl_insert_key(tmpl_main *tmpl, const char *s, const char *def_val) {
 		for (i = 0; i < tmpl->tmpl_keys_size; i++) {
 			tmpl->tmpl_keys[i] = malloc(sizeof(tmpl_key));
 			memset(tmpl->tmpl_keys[i], 0, sizeof(tmpl_key));
+			
+			tmpl->tmpl_keys[i]->value = buffer_init();
 		}
 	}
 
@@ -150,6 +145,8 @@ int tmpl_insert_key(tmpl_main *tmpl, const char *s, const char *def_val) {
 		for (i = tmpl->tmpl_keys_pos; i < tmpl->tmpl_keys_size; i++) {
 			tmpl->tmpl_keys[i] = malloc(sizeof(tmpl_key));
 			memset(tmpl->tmpl_keys[i], 0, sizeof(tmpl_key));
+			
+			tmpl->tmpl_keys[i]->value = buffer_init();
 		}
 	}
 
@@ -187,7 +184,6 @@ int tmpl_insert_key(tmpl_main *tmpl, const char *s, const char *def_val) {
 int tmpl_current_block_append(tmpl_main *tmpl, const char *s) {
 	int i;
 	char *block;
-	int value_len = s ? strlen(s) : 0;
 
 	if (!tmpl) return -1;
 
@@ -200,6 +196,8 @@ int tmpl_current_block_append(tmpl_main *tmpl, const char *s) {
 		for (i = 0; i < tmpl->tmpl_blocks_size; i++) {
 			tmpl->tmpl_blocks[i] = malloc(sizeof(tmpl_block));
 			memset(tmpl->tmpl_blocks[i], 0, sizeof(tmpl_block));
+			
+			tmpl->tmpl_blocks[i]->value = buffer_init();
 		}
 	}
 
@@ -211,6 +209,8 @@ int tmpl_current_block_append(tmpl_main *tmpl, const char *s) {
 		for (i = tmpl->tmpl_blocks_pos; i < tmpl->tmpl_blocks_size; i++) {
 			tmpl->tmpl_blocks[i] = malloc(sizeof(tmpl_block));
 			memset(tmpl->tmpl_blocks[i], 0, sizeof(tmpl_block));
+			
+			tmpl->tmpl_blocks[i]->value = buffer_init();
 		}
 	}
 
@@ -223,26 +223,9 @@ int tmpl_current_block_append(tmpl_main *tmpl, const char *s) {
 	/* search for the block and add the string 's' to the block */
 	for (i = 0; i < tmpl->tmpl_blocks_pos; i++) {
 		if (0 == strcmp(tmpl->tmpl_blocks[i]->name, block)) {
-			if (tmpl->tmpl_blocks[i]->value) {
-				int required_size = tmpl->tmpl_blocks[i]->value_used + value_len + 1;
-				
-				if (tmpl->tmpl_blocks[i]->value_size <= required_size) {
-					tmpl->tmpl_blocks[i]->value_size = required_size + (required_size > 128 ? required_size : 128);
-					
-					tmpl->tmpl_blocks[i]->value =
-						realloc(tmpl->tmpl_blocks[i]->value,
-							tmpl->tmpl_blocks[i]->value_size);
-				}
-				
-				strcpy(tmpl->tmpl_blocks[i]->value + tmpl->tmpl_blocks[i]->value_used, s);
-				tmpl->tmpl_blocks[i]->value_used += value_len;
-			} else {
-				tmpl->tmpl_blocks[i]->value_size = value_len + (value_len > 128 ? value_len : 128);
-				tmpl->tmpl_blocks[i]->value = malloc(tmpl->tmpl_blocks[i]->value_size);
-				strcpy(tmpl->tmpl_blocks[i]->value, s);
-				tmpl->tmpl_blocks[i]->value_used = value_len;
-			}
-
+			
+			buffer_strcat(tmpl->tmpl_blocks[i]->value, s);
+			
 			break;
 		}
 	}
@@ -251,12 +234,8 @@ int tmpl_current_block_append(tmpl_main *tmpl, const char *s) {
 	if (i == tmpl->tmpl_blocks_pos) {
 		tmpl->tmpl_blocks[i]->name = strdup(block);
 		
-		tmpl->tmpl_blocks[i]->value_size = value_len + (value_len > 128 ? value_len : 128);
-		tmpl->tmpl_blocks[i]->value = malloc(tmpl->tmpl_blocks[i]->value_size);
-		strcpy(tmpl->tmpl_blocks[i]->value, s);
+		buffer_strcpy(tmpl->tmpl_blocks[i]->value, s);
 		
-		tmpl->tmpl_blocks[i]->value_used = value_len;
-
 		tmpl->tmpl_blocks_pos++;
 	}
 #if 0
@@ -520,9 +499,7 @@ int tmpl_load_string(tmpl_main *tmpl, const char *string) {
 		return -1;
 	}
 
-	t.buf_len = 128;
-
-	t.buffer = malloc(sizeof(char) * t.buf_len);
+	t.buffer = buffer_init();
 	t.string = string;
 	t.str_pos = 0;
 
@@ -540,10 +517,10 @@ int tmpl_load_string(tmpl_main *tmpl, const char *string) {
 #if 0
 		printf("%s.%d: %s", __FILE__, __LINE__, t.buffer);
 #endif
-		while ((n = pcre_exec(tmpl->match_tag_block, NULL, t.buffer, strlen(t.buffer), offset, 0, ovector, 3 * N)) == 4 || n == 6 || n == 3) {
+		while ((n = pcre_exec(tmpl->match_tag_block, NULL, t.buffer->ptr, t.buffer->used - 1, offset, 0, ovector, 3 * N)) == 4 || n == 6 || n == 3) {
 			slen = ovector[0] - offset;
 			s = malloc(slen + 1);
-			strncpy(s, t.buffer + offset, slen);
+			strncpy(s, t.buffer->ptr + offset, slen);
 			s[slen] = '\0';
 
 			tmpl_current_block_append(tmpl, s);
@@ -556,7 +533,7 @@ int tmpl_load_string(tmpl_main *tmpl, const char *string) {
 				slen = ovector[5] - ovector[4];
 
 				s = malloc(slen + 1);
-				strncpy(s, t.buffer + ovector[4], slen);
+				strncpy(s, t.buffer->ptr + ovector[4], slen);
 				s[slen] = '\0';
 
 				/* handle default value */
@@ -564,7 +541,7 @@ int tmpl_load_string(tmpl_main *tmpl, const char *string) {
 					slen = ovector[7] - ovector[6];
 
 					defval = malloc(slen + 1);
-					strncpy(defval, t.buffer + ovector[6], slen);
+					strncpy(defval, t.buffer->ptr + ovector[6], slen);
 					defval[slen] = '\0';
 				}
 
@@ -580,10 +557,10 @@ int tmpl_load_string(tmpl_main *tmpl, const char *string) {
 				char *s;
 
 				s = malloc(slen + 1);
-				strncpy(s, t.buffer + ovector[10], slen);
+				strncpy(s, t.buffer->ptr + ovector[10], slen);
 				s[slen] = '\0';
 
-				if (*(t.buffer + ovector[8]) == 'B') {
+				if (*(t.buffer->ptr + ovector[8]) == 'B') {
 					char *block;
 					/* add {<blockname>} to the parent */
 					tmpl_current_block_append(tmpl, "{");
@@ -597,7 +574,7 @@ int tmpl_load_string(tmpl_main *tmpl, const char *string) {
 							 "line %d: max. depth (%d) of blocks reached\n",
 							 lc,
 							 TMPL_DEPTH_MAX);
-						free(t.buffer);
+						buffer_free(t.buffer);
 						return -1;
 					}
 
@@ -622,7 +599,7 @@ int tmpl_load_string(tmpl_main *tmpl, const char *string) {
 								 lc,
 								 tmpl->tmpl_current_block,
 								 s);
-							free(t.buffer);
+							buffer_free(t.buffer);
 							return -1;
 						}
 					} else {
@@ -630,7 +607,7 @@ int tmpl_load_string(tmpl_main *tmpl, const char *string) {
 							 "line %d: more END (%s) then BEGIN\n",
 							 lc,
 							 s);
-						free(t.buffer);
+						buffer_free(t.buffer);
 						return -1;
 					}
 				}
@@ -643,14 +620,14 @@ int tmpl_load_string(tmpl_main *tmpl, const char *string) {
 		if (n < 0 && n != PCRE_ERROR_NOMATCH) {
 			M_DEBUG1(tmpl->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_ERRORS,
 				 "execution error while matching: %d\n", n);
-			free(t.buffer);
+			buffer_free(t.buffer);
 			return M_RECORD_HARD_ERROR;
 		}
 
 		/* the rest */
-		slen = strlen(t.buffer) - offset;
+		slen = t.buffer->used - offset;
 		s = malloc(slen + 1);
-		strncpy(s, t.buffer + offset, slen);
+		strncpy(s, t.buffer->ptr + offset, slen);
 		s[slen] = '\0';
 
 		tmpl_current_block_append(tmpl, s);
@@ -663,7 +640,7 @@ int tmpl_load_string(tmpl_main *tmpl, const char *string) {
 			 "line %d: missing END tag for %s\n",
 			 lc,
 			 tmpl_block_depth_names[tmpl_block_depth]);
-		free(t.buffer);
+		buffer_free(t.buffer);
 		return -1;
 	}
 
@@ -674,7 +651,7 @@ int tmpl_load_string(tmpl_main *tmpl, const char *string) {
 	fprintf(stderr, "timer %s: %ld msec\n",
 		__FUNCTION__, timer.span );
 #endif
-	free(t.buffer);
+	buffer_free(t.buffer);
 	return 0;
 }
 
@@ -685,11 +662,8 @@ int tmpl_load_string(tmpl_main *tmpl, const char *string) {
  */
 
 int tmpl_replace_block(tmpl_main *tmpl, const char *block, buffer *replaced_block) {
-	const char *errptr;
-	int erroffset = 0;
 #define N 20 + 1
-	int ovector[3 * N], n, i;
-	pcre * tmpl_keys;
+	int i;
 	tmpl_string t;
 	buffer *str;
 #ifdef MTIMER_ENABLED
@@ -701,10 +675,6 @@ int tmpl_replace_block(tmpl_main *tmpl, const char *block, buffer *replaced_bloc
 #ifdef MTIMER_ENABLED
 	MTIMER_START(timer);
 #endif
-	t.buf_len = 128;
-
-	t.buffer = malloc(sizeof(char) * t.buf_len);
-
 	for (i = 0; i < tmpl->tmpl_blocks_pos; i++) {
 		if (0 == strcmp(tmpl->tmpl_blocks[i]->name, block)) {
 			break;
@@ -718,47 +688,40 @@ int tmpl_replace_block(tmpl_main *tmpl, const char *block, buffer *replaced_bloc
 		return -1;
 	}
 
-	t.string = tmpl->tmpl_blocks[i]->value;
+	t.string = tmpl->tmpl_blocks[i]->value->ptr;
 	t.str_pos = 0;
 
-	if ((tmpl_keys = pcre_compile(
-		"{(.+?)}",
-		0, &errptr, &erroffset, NULL)) == NULL) {
-
-		fprintf(stderr, "%s.%d: rexexp compilation error at %s\n", __FILE__, __LINE__, errptr);
-		free(t.buffer);
-		return -1;
-	}
-	
+	t.buffer = buffer_init();
 	
 	str = replaced_block;
 	
 	str->used = 0;
 	
 	while (tmpl_get_line_from_string(&t)) {
-		int offset = 0;
-		int slen;
-		char *s;
+		char *open, *close, *start;
+		
 #if 0		
-		fprintf(stderr, "%s.%d: %s\n", __FILE__, __LINE__, t.buffer);
+		fprintf(stderr, "%s.%d: %s\n", __FILE__, __LINE__, t.buffer->ptr);
 #endif
-		while ((n = pcre_exec(tmpl_keys, NULL, t.buffer, strlen(t.buffer), offset, 0, ovector, 3 * N)) == 2) {
-			/* before the { */
-			slen = ovector[0] - offset;
-			
-			buffer_strcat_len(str, t.buffer + offset, slen);
+		/* search for { */
+		
+		start = t.buffer->ptr;
+		while (NULL != (open = strchr(start, '{')) &&
+		       NULL != (close = strchr(open, '}')) &&
+		       close - open > 1) {
 
-			/* the substitution */
-			slen = ovector[3] - ovector[2];
+			/* before the { */
+			
+			buffer_strcat_len(str, start, open - start);
 
 			/* find the key and substitute it */
 			for (i = 0; i < tmpl->tmpl_keys_pos; i++) {
-				if (0 == strncmp(tmpl->tmpl_keys[i]->name, t.buffer + ovector[2], slen)) {
-#if 0					
-					fprintf(stderr, "%s.%d: %s\n", __FILE__, __LINE__, tmpl->tmpl_keys[i]->name);
+				if (0 == strncmp(tmpl->tmpl_keys[i]->name, open + 1, close - open - 1)) {
+#if 0
+					fprintf(stderr, "%s.%d: %s, %s\n", __FILE__, __LINE__, tmpl->tmpl_keys[i]->name, tmpl->tmpl_keys[i]->value->ptr);
 #endif
-					if (tmpl->tmpl_keys[i]->value) {
-						buffer_strcat(str, tmpl->tmpl_keys[i]->value);
+					if (tmpl->tmpl_keys[i]->value->used) {
+						buffer_strcat(str, tmpl->tmpl_keys[i]->value->ptr);
 					} else if (tmpl->tmpl_keys[i]->defvalue) {
 						buffer_strcat(str, tmpl->tmpl_keys[i]->defvalue);
 					} else {
@@ -773,32 +736,24 @@ int tmpl_replace_block(tmpl_main *tmpl, const char *block, buffer *replaced_bloc
 			}
 
 			if (i == tmpl->tmpl_keys_pos) {
+				buffer *b;
+					
+				b = buffer_init();
+				
+				buffer_strcpy_len(b, open + 1, close - open - 1);
 				/* ok, we have to extract the key for fprintf */
-				s = malloc(slen + 1);
-				strncpy(s, t.buffer + ovector[2], slen);
-				s[slen] = '\0';
 				M_DEBUG2(tmpl->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_WARNINGS,
 					 "key '%s' not found in block '%s'\n",
-					 s, block);
-				free(s);
+					 b->ptr, block);
+				buffer_free(b);
 			}
 
-			offset = ovector[3] + 1;
+			start = close + 1;
+			
 		}
-
-		if (n < 0 && n != PCRE_ERROR_NOMATCH) {
-			M_DEBUG1(tmpl->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_ERRORS,
-				 "execution error while matching: %d\n", n);
-			free(t.buffer);
-			pcre_free(tmpl_keys);
-			return -1;
-		}
-
-		/* the rest */
-		slen = strlen(t.buffer) - offset;
-
+		
 		/* copy the rest to the end of the string */
-		buffer_strcat_len(str, t.buffer + offset, slen);
+		buffer_strcat(str, start);
 	}
 #ifdef MTIMER_ENABLED
 	MTIMER_STOP(timer);
@@ -807,8 +762,7 @@ int tmpl_replace_block(tmpl_main *tmpl, const char *block, buffer *replaced_bloc
 	fprintf(stderr, "timer %s: %ld msec\n",
 		__FUNCTION__, timer.span );
 #endif
-	free(t.buffer);
-	pcre_free(tmpl_keys);
+	buffer_free(t.buffer);
 	return 0;
 }
 
@@ -840,30 +794,8 @@ int tmpl_set_var (tmpl_main *tmpl, const char *key, const char *value) {
 
 	for (i = 0; i < tmpl->tmpl_keys_pos; i++) {
 		if (0 == strcmp(tmpl->tmpl_keys[i]->name, key)) {
-			int value_len = strlen(value);
+			buffer_strcpy(tmpl->tmpl_keys[i]->value, value);
 			
-			if (tmpl->tmpl_keys[i]->value) {
-				if (value_len >= tmpl->tmpl_keys[i]->value_size) {
-					/* we have to resize */
-					if (tmpl->tmpl_keys[i]->value_size <= value_len) {
-						tmpl->tmpl_keys[i]->value_size = value_len + (value_len > 128 ? value_len : 128);
-						
-						tmpl->tmpl_keys[i]->value =
-							realloc(tmpl->tmpl_keys[i]->value,
-								tmpl->tmpl_keys[i]->value_size);
-					}
-				} else {
-					/* the old string is large enough */
-				}
-			} else {
-				/* we need some new space */
-				tmpl->tmpl_keys[i]->value_size = value_len + (value_len > 128 ? value_len : 128);
-				tmpl->tmpl_keys[i]->value = malloc(tmpl->tmpl_keys[i]->value_size);
-			}
-			
-			strcpy(tmpl->tmpl_keys[i]->value, value);
-			tmpl->tmpl_keys[i]->value_used = value_len;
-
 			break;
 		}
 	}
@@ -907,32 +839,8 @@ int tmpl_append_var (tmpl_main *tmpl, const char *key, const char *value) {
 	/* append the value to the specified variable */
 	for (i = 0; i < tmpl->tmpl_keys_pos; i++) {
 		if (0 == strcmp(tmpl->tmpl_keys[i]->name, key)) {
-			int value_len = strlen(value);
-			if (tmpl->tmpl_keys[i]->value) {
-				int required_size = tmpl->tmpl_keys[i]->value_used + value_len + 1;
-				
-				/* resize if neccesary */
-				/* have to reduces some allocations 
-				 * 
-				 * 179555447  74852           0      0  template.c:951
-				 */
-				if (tmpl->tmpl_keys[i]->value_size <= required_size) {
-					tmpl->tmpl_keys[i]->value_size = required_size + (required_size > 128 ? required_size : 128);
-					
-					tmpl->tmpl_keys[i]->value =
-						realloc(tmpl->tmpl_keys[i]->value,
-							tmpl->tmpl_keys[i]->value_size);
-				}
-				
-				strcpy(tmpl->tmpl_keys[i]->value + tmpl->tmpl_keys[i]->value_used, value);
-				tmpl->tmpl_keys[i]->value_used += value_len;
-			} else {
-				tmpl->tmpl_keys[i]->value_size = value_len + (value_len > 128 ? value_len : 128);
-				tmpl->tmpl_keys[i]->value = malloc(tmpl->tmpl_keys[i]->value_size);
-				strcpy(tmpl->tmpl_keys[i]->value, value);
-				tmpl->tmpl_keys[i]->value_used = value_len;
-			}
-
+			buffer_strcat(tmpl->tmpl_keys[i]->value, value);
+			
 			break;
 		}
 	}
@@ -962,9 +870,8 @@ int tmpl_clear_var (tmpl_main *tmpl, const char *key) {
 
 	for (i = 0; i < tmpl->tmpl_keys_pos; i++) {
 		if (0 == strcmp(tmpl->tmpl_keys[i]->name, key)) {
-			if (tmpl->tmpl_keys[i]->value) free(tmpl->tmpl_keys[i]->value);
-			tmpl->tmpl_keys[i]->value = NULL;
-			tmpl->tmpl_keys[i]->value_size = 0;
+			buffer_reset(tmpl->tmpl_keys[i]->value);
+			
 			break;
 		}
 	}
@@ -1050,7 +957,7 @@ int tmpl_free_keys(tmpl_main *tmpl) {
 	if (!tmpl->tmpl_keys) return -1;
 
 	for (i = 0; i < tmpl->tmpl_keys_size; i++) {
-		if (tmpl->tmpl_keys[i]->value) free(tmpl->tmpl_keys[i]->value);
+		if (tmpl->tmpl_keys[i]->value) buffer_free(tmpl->tmpl_keys[i]->value);
 		if (tmpl->tmpl_keys[i]->defvalue) free(tmpl->tmpl_keys[i]->defvalue);
 		if (tmpl->tmpl_keys[i]->name) free(tmpl->tmpl_keys[i]->name);
 		free(tmpl->tmpl_keys[i]);
@@ -1083,7 +990,7 @@ int tmpl_free_blocks(tmpl_main *tmpl) {
 	if (!tmpl->tmpl_blocks) return -1;
 
 	for (i = 0; i < tmpl->tmpl_blocks_size; i++) {
-		if (tmpl->tmpl_blocks[i]->value) free(tmpl->tmpl_blocks[i]->value);
+		if (tmpl->tmpl_blocks[i]->value) buffer_free(tmpl->tmpl_blocks[i]->value);
 		if (tmpl->tmpl_blocks[i]->name) free(tmpl->tmpl_blocks[i]->name);
 		free(tmpl->tmpl_blocks[i]);
 	}
@@ -1110,7 +1017,7 @@ tmpl_main *tmpl_init() {
 	int erroffset = 0;
 
 	tmpl = malloc(sizeof(tmpl_main));
-
+	
 	/* set everything to zero */
 	memset(tmpl, 0, sizeof(tmpl_main));
 	
@@ -1140,7 +1047,7 @@ int tmpl_free(tmpl_main *tmpl) {
 	pcre_free(tmpl->match_tag_block);
 	
 	buffer_free(tmpl->tmp_buf);
-
+	
 	free(tmpl);
 
 	return 0;
