@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: pictures_day.c,v 1.18 2002/10/23 15:05:39 le_zas Exp $
+** $Id: pictures_day.c,v 1.20 2003/07/31 23:55:46 ostborn Exp $
 */
 #include <stdio.h>
 #include <stdlib.h>
@@ -143,6 +143,7 @@ char *create_pic_31_day(mconfig *ext_conf, mstate *state, const char *subpath) {
 	char int2str[20]; /* 20 is a guess only !! */
 	config_output *conf = ext_conf->plugin_conf;
 	mstate_web *staweb = state->ext;
+	char *str;
 
 	struct tm tm;
 
@@ -249,15 +250,13 @@ char *create_pic_31_day(mconfig *ext_conf, mstate *state, const char *subpath) {
 /* header */
 	x1 = IM_BOX1_X1;
 	y1 = IM_CELLSPACING;
-	gdImageString(im, gdFontSmall, x1, y1, _("Daily usage for "), col_border);
-
-	x1 += strlen(_("Daily usage for ")) * IM_FONT_WIDTH;
-	gdImageString(im, gdFontSmall, x1, y1, get_month_string(state->month,0), col_border);
-
-	x1 += strlen(get_month_string(state->month,0)) * IM_FONT_WIDTH;
-	sprintf(int2str, " %4i",state->year);
-	gdImageString(im, gdFontSmall, x1, y1, int2str, col_border);
+	str = malloc( 1 + strlen(_("Daily usage for %1$s %2$04d")) - 10 + 4 +
+                      strlen( get_month_string(state->month,0) ) );
+	sprintf( str, _("Daily usage for %1$s %2$04d"), get_month_string(state->month,0),
+		 state->year );
 
+	gdImageString(im, gdFontSmall, x1, y1, str, col_border);
+	free(str);
 
 /* border for BOX1 */
 	gdImageRectangle(im,
