@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: pictures_hour.c,v 1.15 2002/10/23 15:05:39 le_zas Exp $
+** $Id: pictures_hour.c,v 1.18 2003/08/01 00:08:55 ostborn Exp $
 */
 #include <stdio.h>
 #include <stdlib.h>
@@ -99,6 +99,7 @@ char *create_pic_24_hour(mconfig *ext_conf, mstate *state, const char *subpath)
 	char int2str[20]; /* 20 is a guess only !! */
 	config_output *conf = ext_conf->plugin_conf;
 	mstate_web *staweb = state->ext;
+	char *str;
 
 	static char href[255] = "";
 
@@ -183,14 +184,13 @@ char *create_pic_24_hour(mconfig *ext_conf, mstate *state, const char *subpath)
 /* header */
 	x1 = IM_BOX1_X1;
 	y1 = IM_CELLSPACING;
-	gdImageString(im, gdFontSmall, x1, y1, _("Hourly usage for "), col_border);
-
-	x1 += strlen(_("Hourly usage for ")) * IM_FONT_WIDTH;
-	gdImageString(im, gdFontSmall, x1, y1, get_month_string(state->month,0), col_border);
-
-	x1 += strlen(get_month_string(state->month,0)) * IM_FONT_WIDTH;
-	sprintf(int2str, " %4i",state->year);
-	gdImageString(im, gdFontSmall, x1, y1, int2str, col_border);
+	str = malloc( strlen( _("Hourly usage for %1$s %2$04d") ) - 5 + 
+	                    strlen( get_month_string(state->month,0)) );
+	sprintf( str, _("Hourly usage for %1$s %2$04d"), 
+	         get_month_string(state->month,0), state->year );
+	gdImageString(im, gdFontSmall, x1, y1, str, col_border);
+	
+	free(str);
 
 /* border for BOX1 */
 	gdImageRectangle(im,
