@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: process.c,v 1.10 2002/10/26 13:45:51 ostborn Exp $
+** $Id: process.c,v 1.13 2003/07/29 12:38:38 miham Exp $
 */
 
 #include <libintl.h>
@@ -50,7 +50,7 @@
 #include "plugin_config.h"
 
 #define M_TRAFFIC_DIRECTION_UNSET	0
-#define M_TRAFFIC_DIRECTION_INCOMMING	1
+#define M_TRAFFIC_DIRECTION_INCOMING	1
 #define M_TRAFFIC_DIRECTION_OUTGOING	2
 #define M_TRAFFIC_DIRECTION_INTERNAL	3
 #define M_TRAFFIC_DIRECTION_EXTERNAL	4
@@ -80,13 +80,11 @@ int mplugins_processor_traffic_insert_record(mconfig *ext_conf, mlist *state_lis
 		mlist_insert(state_list, data);
 	}
 
-	if (record->ext_type != M_RECORD_TYPE_TRAFFIC) return -1;
-
-	if (record->ext == NULL) return -1;
-
+	if (record->ext_type != M_RECORD_TYPE_TRAFFIC || record->ext == NULL ) return -1;
+	
 	rectrf = record->ext;
 
-	if (rectrf->ext_type == M_RECORD_TYPE_TRAFFIC_FLOW && record->ext != NULL)
+	if (rectrf->ext_type == M_RECORD_TYPE_TRAFFIC_FLOW && rectrf->ext != NULL)
 		recflw = rectrf->ext;
 
 	if (state->ext) {
@@ -109,7 +107,7 @@ int mplugins_processor_traffic_insert_record(mconfig *ext_conf, mlist *state_lis
 
 
 	switch(1) {
-		case M_TRAFFIC_DIRECTION_INCOMMING:
+		case M_TRAFFIC_DIRECTION_INCOMING:
 			stasub = statrf->incoming;
 			break;
 		case M_TRAFFIC_DIRECTION_OUTGOING:
@@ -130,7 +128,7 @@ int mplugins_processor_traffic_insert_record(mconfig *ext_conf, mlist *state_lis
 		data = mdata_Traffic_create(
 					    rectrf->src,
 					    rectrf->dst,
-					    rectrf->xfer_incomming,
+					    rectrf->xfer_incoming,
 					    rectrf->xfer_outgoing,
 					    recflw ? recflw->src_port : 0,
 					    recflw ? recflw->dst_port : 0,
