@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.c,v 1.45 2003/04/18 18:45:05 ostborn Exp $
+** $Id: plugin_config.c,v 1.46 2003/07/18 07:23:56 ostborn Exp $
 */
 
 #include <stdlib.h>
@@ -139,6 +139,7 @@ int mplugins_processor_web_dlclose(mconfig *ext_conf) {
 	mlist_free(conf->hide_host);
 	mlist_free(conf->hide_brokenlinks);
 	mlist_free(conf->hide_brokenlinks_ref);
+	mlist_free(conf->hide_robots);
 	mlist_free(conf->hide_extension);
 	mlist_free(conf->hide_hostmask);
 	mlist_free(conf->match_searchengine);
@@ -150,6 +151,7 @@ int mplugins_processor_web_dlclose(mconfig *ext_conf) {
 	mlist_free(conf->group_brokenlinks);
 	mlist_free(conf->group_url);
 	mlist_free(conf->group_searchstrings);
+	mlist_free(conf->group_robots);
 	mlist_free(conf->group_extension);
 	mlist_free(conf->group_searchengine);
 
@@ -280,8 +282,6 @@ int mplugins_processor_web_set_defaults(mconfig *ext_conf) {
 		const char *errptr;
 		int erroffset = 0;
 
-		l = conf->splitby;
-
 		if ((match = pcre_compile("^([a-z]+),\\s*\"(.*)\",\\s*(.+)\\s*$",
 			0, &errptr, &erroffset, NULL)) == NULL) {
 			fprintf(stderr, "%s.%d: rexexp compilation error at %s\n", __FILE__, __LINE__, errptr);
@@ -289,7 +289,7 @@ int mplugins_processor_web_set_defaults(mconfig *ext_conf) {
 		}
 
 		/* doing some tests with the string */
-		while (l) {
+		for (l = conf->splitby; l; l = l->next) {
 			mdata *data = l->data;
 #define N 20 + 1
 			int ovector[3 * N], n, i;
@@ -330,11 +330,9 @@ int mplugins_processor_web_set_defaults(mconfig *ext_conf) {
 
 				pcre_get_substring_list(data->key, ovector, n, &list);
 
-				i = 0;
-				while (field_values[i].string) {
-					if (!strcmp(field_values[i].string, list[1]))
-						break;
-					i++;
+				/* search split def */
+				for (i = 0; field_values[i].string; i++) {
+					if (0 == strcmp(field_values[i].string, list[1])) break;
 				}
 
 				if (field_values[i].string) {
@@ -356,8 +354,6 @@ int mplugins_processor_web_set_defaults(mconfig *ext_conf) {
 			} else {
 				fprintf(stderr, "%s.%d: too few fields matched: %d\n", __FILE__, __LINE__, n);
 			}
-
-			l = l->next;
 		}
 
 		pcre_free(match);
