@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: process.c,v 1.68 2003/04/18 18:45:05 ostborn Exp $
+** $Id: process.c,v 1.70 2003/07/18 11:41:39 ostborn Exp $
 */
 
 #include <libintl.h>
@@ -466,18 +466,15 @@ int is_file(mlogrec_web *record) {
 
 int is_page(mconfig *ext_conf, mlogrec_web *record) {
 	config_processor *conf = ext_conf->plugin_conf;
-	mlist *l = conf->page_type;
+	mlist *l;
 	buffer *url = record->req_url;
-
-	if (url->used == 0 || l == NULL) return 0;
 	
-	for (; l; l = l->next) {
+	if (url->used == 0) return 0;
+	
+	for (l = conf->page_type; l; l = l->next) {
 		mdata *data = l->data;
 		
-		if (data && strmatch(data->data.match.match, data->data.match.study, url->ptr, url->used)) {
-#if 0
-			fprintf(stderr, "%s.%d: is a page: %s\n", __FILE__, __LINE__, url->ptr);
-#endif
+		if (data && strmatch(data->data.match.match, data->data.match.study, url->ptr, url->used - 1)) {
 			return 1;
 		}
 	}
@@ -865,22 +862,22 @@ int process_searchengine(mconfig *ext_conf, mstate *state, mlogrec_web_extclf *r
 
 	mlist *l = conf->searchengines;
 	mstate_web *staweb = state->ext;
-	int refurl_len, getvar_len;
 
 	if (!l) return 0;
 
 	if (!(record->ref_getvars->used && record->ref_url->used)) return 0;
 
-	refurl_len = record->ref_url->used;
-	getvar_len = record->ref_getvars->used;
-
 	full = buffer_init();
-	buffer_strcpy(full, record->ref_url->ptr);
-	buffer_strcat(full, "?");
-	buffer_strcat(full, record->ref_getvars->ptr);
-
-	if (ignore_field(ext_conf, full, M_WEB_IGNORE_SEARCHENGINE)) return 0;
+	buffer_prepare_copy(full, record->ref_url->used + record->ref_getvars->used + 1);
+	buffer_strcpy_len(full, record->ref_url->ptr, record->ref_url->used - 1);
+	buffer_strcat_len(full, "?", 1);
+	buffer_strcat_len(full, record->ref_getvars->ptr, record->ref_getvars->used - 1);
 
+	if (ignore_field(ext_conf, full, M_WEB_IGNORE_SEARCHENGINE)) {
+		buffer_free(full);
+		return 0;
+	}
+	
 	for (l = conf->match_searchengine; l; l = l->next) {
 		mdata *data = l->data;
 #define N 20
@@ -895,7 +892,7 @@ int process_searchengine(mconfig *ext_conf, mstate *state, mlogrec_web_extclf *r
 		}
 
 		/* match the string */
-		if ((n = pcre_exec(data->data.match.match, data->data.match.study, full->ptr, refurl_len + getvar_len + 1, 0, 0, ovector, 3 * N)) < 0) {
+		if ((n = pcre_exec(data->data.match.match, data->data.match.study, full->ptr, full->used - 1, 0, 0, ovector, 3 * N)) < 0) {
 			if (n != PCRE_ERROR_NOMATCH) {
 				fprintf(stderr, "%s.%d: execution error while matching: %d\n", __FILE__, __LINE__, n);
 				return 0;
